For TCK data (see read.dti.tck), a tract is an n x 3
numeric matrix of coordinates. For TRK data (see read.dti.trk), a
tract is a named list with the entries coords (n x 3 matrix),
num_points (integer), scalars (n x n_scalars matrix or NULL)
and properties (numeric vector or NULL).
This returns a copy of the requested tract, the data is stored in a single
matrix internally.