Learn R Programming

freesurferformats (version 1.1.0)

.write.numeric.table: Write a numeric table to a text file, one matrix row per line.

Description

Write a numeric table to a text file, one matrix row per line.

Usage

.write.numeric.table(filepath, m)

Value

NULL, invisibly.

Arguments

filepath

character string, path to the output file. Files ending in .gz are gzip-compressed.

m

numeric matrix, the table to write.