analyze.read.header.internal: Read ANALYZE 7.5 header from file.

View source: R/read_analyze.R

analyze.read.header.internalR Documentation

Read ANALYZE 7.5 header from file.

Description

Read ANALYZE 7.5 header from file.

Usage

analyze.read.header.internal(filepath, little_endian = TRUE)

Arguments

filepath

character string, the path to the .hdr file. The base name without the extension is accepted as well, see analyze.pair.files.

little_endian

logical, leave this alone. The endianness is detected automatically, and messing with this parameter only makes the detection report a wrong endianness for a file of the other one.

Value

named list, the ANALYZE 7.5 header. See read.analyze.header.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.