assert.surface: Stop unless surf is an fs.surface
Description
Stop unless surf is an fs.surface
Usage
assert.surface(surface, param_name = "surface")
Value
Called for the side effect of stopping if surf is not an fs.surface instance.
Arguments
- param_name
character string, used in stop message to identify the parameter.
- surf
fs.surface instance or anything else