axcodes2ornt: Convert axis codes to an orientation array.

View source: R/trackvis_affine.R

axcodes2orntR Documentation

Convert axis codes to an orientation array.

Description

Convert axis codes to an orientation array.

Usage

axcodes2ornt(axcodes)

Arguments

axcodes

character vector with one code per input axis, e.g. c('L','P','S') for a file whose first voxel axis points left.

Value

numeric matrix with 3 rows and 2 columns, see io.orientation.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.