R/gifti_xml_tools.R
cdata.Rd
Create CDATA element string from string.
cdata(string)
character string, the input string, freeform text. Must not contain the cdata start and end tags.
character string, the input wrapped in the cdata tags
This returns a string, not an XML node. See xml_cdata if you want a node.
xml_cdata