check_all_finite: Check that a numeric vector or matrix contains only finite...

View source: R/safety_checks.R

check_all_finiteR Documentation

Check that a numeric vector or matrix contains only finite values.

Description

Stops with an error if the input contains NA, NaN, or Inf values.

Usage

check_all_finite(x, label = "data")

Arguments

x

a numeric vector or matrix.

label

character string, a human-readable label for the data (used in the error message).

Value

TRUE (invisibly) if all values are finite. Stops otherwise.


freesurferformats documentation built on Sept. 8, 2026, 5:08 p.m.