cifti.assign.rows: Assign rows of an array, reordered or repeated.

View source: R/read_cifti.R

cifti.assign.rowsR Documentation

Assign rows of an array, reordered or repeated.

Description

Assign rows of an array, reordered or repeated.

Usage

cifti.assign.rows(target, to, from, data)

Arguments

target

array, the array to write to.

to

integer vector, the row indices of target to write.

from

integer vector, the row indices of data to read.

data

array, the source array.

Value

target with the requested rows assigned.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.