cifti.axis.series: Create a CIFTI-2 axis for a series.

View source: R/write_cifti_axes.R

cifti.axis.seriesR Documentation

Create a CIFTI-2 axis for a series.

Description

A series axis describes a dimension that holds an ordered sequence of samples, usually the time points of a .dtseries or .ptseries file. The value of series index i (0-based) is (start + i * step) * 10^exponent, in the unit that unit names.

Usage

cifti.axis.series(
  number_of_series_points,
  start = 0,
  step = 1,
  exponent = 0L,
  unit = "SECOND"
)

Arguments

number_of_series_points

integer, the number of samples, which must match the size of that matrix dimension of the data.

start

numeric, the value of the first sample.

step

numeric, the difference between consecutive samples.

exponent

integer, the power of ten the values are in (e.g. -3 for milliseconds).

unit

character string, one of 'SECOND', 'HERTZ', 'METER' or 'RADIAN'.

Value

a named list with the entries 'type' and 'series', an axis to be passed to cifti.header.from.axes or write.cifti.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.brain.model.surface(), cifti.brain.model.volume(), cifti.dim.labels(), cifti.file.type.for.axes(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.series.info(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

axis <- cifti.axis.series(10L, start = 0, step = 0.72, unit = "SECOND")
axis$series$number_of_series_points


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.