cifti.axis.surface.sizes: Get the surface sizes of an axis as a named vector.

View source: R/write_cifti_fs.R

cifti.axis.surface.sizesR Documentation

Get the surface sizes of an axis as a named vector.

Description

Get the surface sizes of an axis as a named vector.

Usage

cifti.axis.surface.sizes(axis)

Arguments

axis

an axis of type 'CIFTI_INDEX_TYPE_BRAIN_MODELS'.

Value

named integer vector or NULL, the number of vertices per structure, see cifti.axis.brain.models.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.