cifti.brain.model.volume: Create a CIFTI-2 brain model entry for volume voxels.

View source: R/write_cifti_axes.R

cifti.brain.model.volumeR Documentation

Create a CIFTI-2 brain model entry for volume voxels.

Description

A volume brain model entry describes the voxels of one subcortical structure, as 0-based IJK indices into the voxel grid of the volume that is part of the same axis (see cifti.volume). If the indices are NULL, the model covers all voxels of that grid.

Usage

cifti.brain.model.volume(structure, voxel_indices_ijk = NULL)

Arguments

structure

character string, the brain structure, see cifti.structure.canonical for the accepted spellings.

voxel_indices_ijk

n x 3 integer matrix or NULL, the 0-based voxel indices, one voxel per row. A vector of length 3*n is accepted as well and interpreted as the rows.

Value

a named list, one brain model entry, to be passed to cifti.axis.brain.models.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.axis.series(), cifti.brain.model.surface(), cifti.dim.labels(), cifti.file.type.for.axes(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.series.info(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

voxels <- matrix(c(0L, 0L, 2L, 1L, 0L, 2L), ncol = 3L, byrow = TRUE)
model <- cifti.brain.model.volume("CEREBELLUM", voxels)
model$index_count


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.