cifti.brainordinate.dims: Get all matrix dimensions of a CIFTI-2 file that hold brain...

View source: R/read_cifti.R

cifti.brainordinate.dimsR Documentation

Get all matrix dimensions of a CIFTI-2 file that hold brain models.

Description

A single MatrixIndicesMap element can apply to both matrix dimensions (this is the case for connectome files like .dconn and .pconn), so the dimensions have to be counted, not the mapping elements.

Usage

cifti.brainordinate.dims(cii)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

Value

integer vector, the dimensions that contain brain models (usually one, two for a file like .dconn).


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.