cifti.check.axes: Check a list of axes and name the dimensions.

View source: R/write_cifti.R

cifti.check.axesR Documentation

Check a list of axes and name the dimensions.

Description

Check a list of axes and name the dimensions.

Usage

cifti.check.axes(axes)

Arguments

axes

list of axes, see cifti.header.from.axes.

Value

the list, with the axes named by their matrix dimension.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.