cifti.data.for.all.vertices: Assemble the data values of all vertices for a file without a...

View source: R/write_cifti_fs.R

cifti.data.for.all.verticesR Documentation

Assemble the data values of all vertices for a file without a template.

Description

Assemble the data values of all vertices for a file without a template.

Usage

cifti.data.for.all.vertices(data, structures, what = "data")

Arguments

data

the data, see write.fs.morph.cifti.

structures

character vector, the canonical structure names, in file order.

what

character string, a description of the data, used in error messages.

Value

a matrix with one row per vertex (structures one after the other) and one column per map.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.