cifti.data.for.grayordinates: Select the data values of the grayordinates of a file.

View source: R/write_cifti_fs.R

cifti.data.for.grayordinatesR Documentation

Select the data values of the grayordinates of a file.

Description

Select the data values of the grayordinates of a file.

Usage

cifti.data.for.grayordinates(data, structures, index_table, what)

Arguments

data

the data, see write.fs.morph.cifti.

structures

character vector, the canonical structure names, in file order.

index_table

the brainordinate table, see cifti.grayordinates.

what

character string, a description of the data, used in error messages.

Value

a matrix with one row per grayordinate (in file order) and one column per map.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.