cifti.data.per.structure: Get the per-structure data of one structure.

View source: R/write_cifti_fs.R

cifti.data.per.structureR Documentation

Get the per-structure data of one structure.

Description

Get the per-structure data of one structure.

Usage

cifti.data.per.structure(data, structure_name, what)

Arguments

data

the data, see write.fs.morph.cifti.

structure_name

character string, the canonical structure name.

what

character string, a description of the data, used in error messages.

Value

a matrix with one row per vertex of the complete surface and one column per map.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.