cifti.data.surface.size: The number of vertices of the surface of one structure.

View source: R/write_cifti_fs.R

cifti.data.surface.sizeR Documentation

The number of vertices of the surface of one structure.

Description

The number of vertices of the surface of one structure.

Usage

cifti.data.surface.size(data, structure_name)

Arguments

data

the data, see write.fs.morph.cifti.

structure_name

character string, the canonical structure name.

Value

integer, the number of vertices.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.