cifti.dim.labels: Get axis labels for a matrix dimension of a CIFTI-2 file.

View source: R/read_cifti.R

cifti.dim.labelsR Documentation

Get axis labels for a matrix dimension of a CIFTI-2 file.

Description

Get a label for each index of one matrix dimension of a CIFTI-2 file, e.g. the map names of a .dscalar, the parcel names of a .pconn or identifiers for the grayordinates of a dense file. This is what read.cifti uses to name the dimensions of the data array.

Usage

cifti.dim.labels(cii, dim = 0L)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

dim

integer, the matrix dimension to get the brain models for. CIFTI-2 files have two dimensions, so this is usually 0 (Workbench calls it the ROW dimension) or 1 (the COLUMN dimension). See read.cifti.header for details on the dimensions.

Value

character vector of length cii$matrix$dim_sizes[dim + 1], the labels, or NULL if no labels are known for this kind of dimension.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.axis.series(), cifti.brain.model.surface(), cifti.brain.model.volume(), cifti.file.type.for.axes(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.series.info(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

cifti_file <- system.file("extdata", "cifti", "tiny.ptseries.nii", package = "freesurferformats")
cii <- read.cifti.header(cifti_file)
cifti.dim.labels(cii, dim = 1L)


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.