cifti.dim.to.front: Move one dimension of an array to the front.

View source: R/read_cifti.R

cifti.dim.to.frontR Documentation

Move one dimension of an array to the front.

Description

Move one dimension of an array to the front.

Usage

cifti.dim.to.front(data, dim)

Arguments

data

the array.

dim

integer, the dimension to move, counted from 0 (CIFTI style).

Value

the array with the requested dimension first, and all other dimensions in their original order.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.