cifti.file.type.for.extension: The CIFTI-2 file type a file name names.

View source: R/write_cifti_connectome.R

cifti.file.type.for.extensionR Documentation

The CIFTI-2 file type a file name names.

Description

The CIFTI-2 file type a file name names.

Usage

cifti.file.type.for.extension(filepath)

Arguments

filepath

character string, a file name.

Value

character string, the standard file name extension the name ends with (e.g. '.pscalar.nii'), or the empty string if it does not end with one of them.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.