cifti.grayordinates.for.model: Expand one brain model entry into a brainordinate table.

View source: R/read_cifti.R

cifti.grayordinates.for.modelR Documentation

Expand one brain model entry into a brainordinate table.

Description

Expand one brain model entry into a brainordinate table.

Usage

cifti.grayordinates.for.model(map, model)

Arguments

map

the indices map the brain model belongs to, see cifti.map.for.dim.

model

one brain model entry of the map.

Value

a data.frame, see cifti.grayordinates.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.