cifti.merge.axes: Merge explicitly given axes with the axes of a template.

cifti.merge.axesR Documentation

Merge explicitly given axes with the axes of a template.

Description

Merge explicitly given axes with the axes of a template.

Usage

cifti.merge.axes(axes, template_cii)

Arguments

axes

list of axes or NULL, see write.cifti.

template_cii

an fs.cifti object or NULL.

Value

the merged list of axes, named by matrix dimension.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.