cifti.parse.xml: Parse the CIFTI XML metadata.

View source: R/read_cifti_header.R

cifti.parse.xmlR Documentation

Parse the CIFTI XML metadata.

Description

Parse the CIFTI XML metadata.

Usage

cifti.parse.xml(xml_text, filepath = "", niiheader = NULL)

Arguments

xml_text

character string, the XML document.

filepath

character string, the path of the file the XML was read from. Only used in error messages.

niiheader

the NIFTI-2 header of the file, required to determine the sizes of the matrix dimensions.

Value

an fs.cifti object, see read.cifti.header.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.