cifti.read.values: Read raw values from the data section of a CIFTI-2 file.

View source: R/read_cifti.R

cifti.read.valuesR Documentation

Read raw values from the data section of a CIFTI-2 file.

Description

Read raw values from the data section of a CIFTI-2 file.

Usage

cifti.read.values(cii, num_values, skip_values = 0L, fh = NULL)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

num_values

integer, the number of values to read.

skip_values

integer, the number of values to skip first.

fh

optional connection to the file, positioned at the start of the data section if skip_values is 0. Will be opened (and closed) if left at NULL.

Value

vector of values, see read.nifti.values.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.