cifti.series.info: Get the series information of a CIFTI-2 file.

View source: R/read_cifti_header.R

cifti.series.infoR Documentation

Get the series information of a CIFTI-2 file.

Description

Get the description of the series dimension of a CIFTI-2 file, e.g. the time points of a .dtseries or .ptseries file. The time (or other unit) of the series index i is (start + i * step) * 10^exponent, with i starting at 0.

Usage

cifti.series.info(cii, dim = 0L)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

dim

integer, the matrix dimension to get the brain models for. CIFTI-2 files have two dimensions, so this is usually 0 (Workbench calls it the ROW dimension) or 1 (the COLUMN dimension). See read.cifti.header for details on the dimensions.

Value

a named list with the entries 'number_of_series_points' (integer), 'start' (numeric), 'step' (numeric), 'exponent' (integer) and 'unit' (character string, one of 'SECOND', 'HERTZ', 'METER', 'RADIAN'), or NULL if the specified matrix dimension is not a series. To check whether a dimension is a series, inspect the field 'type' of the corresponding entry of cii$matrix$indices_maps.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.axis.series(), cifti.brain.model.surface(), cifti.brain.model.volume(), cifti.dim.labels(), cifti.file.type.for.axes(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

cifti_file <- system.file("extdata", "cifti", "tiny.dtseries.nii", package = "freesurferformats")
cii <- read.cifti.header(cifti_file)
cifti.series.info(cii, dim = 0L)


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.