cifti.structure.data.one: Extract the data of one brain structure (internal).

View source: R/read_cifti.R

cifti.structure.data.oneR Documentation

Extract the data of one brain structure (internal).

Description

Extract the data of one brain structure (internal).

Usage

cifti.structure.data.one(cii, map, brainordinates, data, structure)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

map

the indices map of the brainordinate dimension, see cifti.map.for.dim.

brainordinates

the brainordinate table, see cifti.grayordinates.

data

the data array with the brainordinate dimension first, see cifti.dim.to.front.

structure

character string, the canonical name of the structure.

Value

a named list, see cifti.structure.data.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.