cifti.structure.from.specifier: Resolve a user-supplied structure specifier to a canonical...

View source: R/cifti.R

cifti.structure.from.specifierR Documentation

Resolve a user-supplied structure specifier to a canonical name.

Description

Accept the structure spellings the user-facing readers support: a structure name in any of the supported spellings, or the index of a structure in the file (deprecated, but part of the documented interface of the readers).

Usage

cifti.structure.from.specifier(cii, brain_structure)

Arguments

cii

an fs.cifti instance, see read.cifti.header.

brain_structure

character string or integer, the specifier.

Value

character string, the canonical structure name.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.