cifti.structure.short: Get the short name of a CIFTI brain structure.

View source: R/read_cifti_header.R

cifti.structure.shortR Documentation

Get the short name of a CIFTI brain structure.

Description

Strip the CIFTI_STRUCTURE_ prefix from a brain structure name, normalizing it first, see cifti.structure.canonical.

Usage

cifti.structure.short(brain_structure)

Arguments

brain_structure

character string, a brain structure name in any of the supported spellings.

Value

character string, the structure name without the prefix (e.g. 'CORTEX_LEFT').


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.