cifti.surface.vertex.counts: Get the number of vertices of the surfaces declared in a...

View source: R/read_cifti_header.R

cifti.surface.vertex.countsR Documentation

Get the number of vertices of the surfaces declared in a CIFTI mapping.

Description

Get the number of vertices of the surfaces declared in a CIFTI mapping.

Usage

cifti.surface.vertex.counts(map)

Arguments

map

a parsed indices map, see cifti.parse.indices.map.

Value

named integer vector, the number of vertices per canonical brain structure short name (e.g. 'CORTEX_LEFT'). Empty if the mapping declares no surfaces.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.