cifti.validate.brain.models: Validate the brain model entries of a CIFTI mapping.

View source: R/read_cifti_header.R

cifti.validate.brain.modelsR Documentation

Validate the brain model entries of a CIFTI mapping.

Description

Validate the brain model entries of a CIFTI mapping.

Usage

cifti.validate.brain.models(map, dim_size, filepath = "")

Arguments

map

a parsed indices map, see cifti.parse.indices.map.

filepath

character string, the file path, used in error messages.

Value

NULL, invisibly. Stops with a descriptive error if an entry is inconsistent.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.