cifti.validate.dims.coverage: Check that all matrix dimensions are described exactly once.

View source: R/read_cifti_header.R

cifti.validate.dims.coverageR Documentation

Check that all matrix dimensions are described exactly once.

Description

Check that all matrix dimensions are described exactly once.

Usage

cifti.validate.dims.coverage(indices_maps, dim_sizes, filepath = "")

Arguments

indices_maps

list of parsed indices maps.

filepath

character string, the path of the file the XML was read from. Only used in error messages.

Value

NULL, invisibly. Stops if a dimension is described twice or not at all.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.