cifti.validate.parcels: Validate the parcels of a CIFTI mapping.

View source: R/read_cifti_header.R

cifti.validate.parcelsR Documentation

Validate the parcels of a CIFTI mapping.

Description

Validate the parcels of a CIFTI mapping.

Usage

cifti.validate.parcels(map, filepath = "")

Arguments

map

a parsed indices map, see cifti.parse.indices.map.

filepath

character string, the file path, used in error messages.

Value

NULL, invisibly. Stops with a descriptive error if a parcel refers to vertices outside of a declared surface.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.