Find vertex index closest to given query coordinate using Euclidean distance.
Source:R/surface_dist.R
closest.vert.to.point.RdFind vertex index closest to given query coordinate using Euclidean distance.
Value
named list with entries: 'vertex_id' integer vector, the index of the closest vertex, and 'dist': double vector, the Euclidean distance to that vertex.
See also
Other Euclidean distance util functions:
vertex.euclid.dist(),
vertexdists.to.point()