Learn R Programming

freesurferformats (version 1.1.0)

coord.bbox: Compute the bounding box of a set of coordinates.

Description

Compute the bounding box of a set of coordinates.

Usage

coord.bbox(coords)

Value

numeric vector of length 6, c(xmin, xmax, ymin, ymax, zmin, zmax), or NULL if there are no rows.

Arguments

coords

numeric matrix with 3 columns.