dot-dti.bzero.threshold: Get the b-value threshold below which a volume counts as a...

.dti.bzero.thresholdR Documentation

Get the b-value threshold below which a volume counts as a b=0 volume.

Description

MRtrix3 treats any volume whose b-value is at most this threshold as a b=0 volume. See the BZeroThreshold configuration entry of MRtrix3, which defaults to 10 s/mm^2.

Usage

.dti.bzero.threshold()

Value

numeric scalar, the threshold in s/mm^2.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.