| .read.dti.tcktsf | R Documentation |
Read DTI tracking data from MRtrix TCK and TSF files.
.read.dti.tcktsf(
filepath,
max_tracks = Inf,
skip_tracks = 0L,
bbox = NULL,
chunk_values = 4e+06
)
filepath |
character string, path to the |
max_tracks |
numeric, the maximum number of tracks to read. Use
|
skip_tracks |
integer, the number of tracks to skip before reading any. Skipped tracks are never held in memory. |
bbox |
numeric vector of length 6 or NULL. If given, only tracks that
have at least one point inside the box are read, the box is given as
|
chunk_values |
integer, the number of payload values that are read per chunk. This is an advanced tuning parameter that does not change the result, only the peak memory usage (at most one chunk is buffered at a time) and the granularity of the file reads. The default of 4e6 values corresponds to about 32 MB of doubles. Lower it on a machine with very little free memory. |
named list with entries header and either tracks (for
TCK files) or scalars (for TSF files).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.