dot-write.numeric.table: Write a numeric table to a text file, one matrix row per...

.write.numeric.tableR Documentation

Write a numeric table to a text file, one matrix row per line.

Description

Write a numeric table to a text file, one matrix row per line.

Usage

.write.numeric.table(filepath, m)

Arguments

filepath

character string, path to the output file. Files ending in .gz are gzip-compressed.

m

numeric matrix, the table to write.

Value

NULL, invisibly.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.