Ensure that the optional data is available locally in the package cache. Will try to download the data only if it is not available. This data is not required for the package to work, but it is used in the examples, in the unit tests and also in the example code from the vignette. Downloading it is highly recommended.
Arguments
- dl_from
string, the source to download from. Either
"rcmd.org"(the default) or"github_fsf_release"to use the GitHub release at https://github.com/dfsp-spirit/freesurferformats/releases/tag/nitestdata-v1.- scheme
string, the URL scheme to use. Either
"https"(the default) or"http". Both the rcmd.org server and GitHub support HTTPS, so this should rarely need to be changed.