View source: R/read_fs_surface.R
| faces.quad.to.tris | R Documentation |
Convert quadrangular faces or polygons to triangular ones.
faces.quad.to.tris(quad_faces)
quad_faces |
nx4 integer matrix, the indices of the vertices making up the n quad faces. |
2nx3 integer matrix, the indices of the vertices making up the 2n tris faces.
This function does no fancy remeshing, it simply splits each quad into two triangles.
Other mesh functions:
read.fs.surface(),
read.fs.surface.asc(),
read.fs.surface.bvsrf(),
read.fs.surface.geo(),
read.fs.surface.gii(),
read.fs.surface.ico(),
read.fs.surface.obj(),
read.fs.surface.off(),
read.fs.surface.ply(),
read.fs.surface.vtk(),
read.mesh.brainvoyager(),
read_nisurface(),
read_nisurfacefile(),
write.fs.surface(),
write.fs.surface.asc(),
write.fs.surface.byu(),
write.fs.surface.gii(),
write.fs.surface.mz3(),
write.fs.surface.vtk()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.