Convert tris faces to quad faces by simple merging.
Source:R/read_fs_surface.R
faces.tris.to.quad.RdThis is experimental. Note that it can only work if the number of 'tris_faces' is even, as two consecutive tris-faces will be merged into one quad face. We could set the index to NA in that case, but I do not know how FreeSurfer handles this, so we do not guess.