Learn R Programming

freesurferformats (version 1.0.1)

fileopen.gz.or.not: Get connection to a binary file, gz or not.

Description

Get connection to a binary file, gz or not.

Usage

fileopen.gz.or.not(filepath)

Arguments

filepath

path to the binary file.