fileopen.write.gz.or.not: Open a connection for writing, with gzip support based on the...

View source: R/write_analyze.R

fileopen.write.gz.or.notR Documentation

Open a connection for writing, with gzip support based on the file name.

Description

Open a connection for writing, with gzip support based on the file name.

Usage

fileopen.write.gz.or.not(filepath)

Arguments

filepath

character string, the path of the file to write.

Value

a connection, either a gzfile or a plain file connection.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.