finite.rows: Check which rows of a matrix consist of finite values only.

View source: R/read_dti_tcktsf.R

finite.rowsR Documentation

Check which rows of a matrix consist of finite values only.

Description

Check which rows of a matrix consist of finite values only.

Usage

finite.rows(mat)

Arguments

mat

numeric matrix.

Value

logical vector with one entry per row.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.