Learn R Programming

freesurferformats (version 1.1.0)

fs.tracts.point.count: Get the total number of points of all tracts.

Description

Get the total number of points of all tracts.

Usage

fs.tracts.point.count(tracts)

Value

integer, the total number of points.

Arguments

tracts

an fs.tracts instance.