View source: R/gifti_xml_tools.R
| gifti_xml_add_global_metadata | R Documentation |
Add metadata to GIFTI XML tree.
gifti_xml_add_global_metadata(xmltree, metadata_named_list, as_cdata = TRUE)
xmltree |
XML tree from xml2 |
metadata_named_list |
named list, the metadata entries |
as_cdata |
logical, whether to wrap the value in cdata tags |
the modified tree.
Assumes that there already exists a global MetaData node. Also not that this is not supposed to be used for adding metadata to datarrays.
## Not run:
xmltree <- gifti_xml(list(rep(3.1, 3L), matrix(seq(6) + 0.1, nrow = 2L)))
newtree <- gifti_xml_add_global_metadata(xmltree, list("User" = "Me", "Weather" = "Great"))
gifti_xsd <- "https://www.nitrc.org/frs/download.php/158/gifti.xsd"
xml2::xml_validate(newtree, xml2::read_xml(gifti_xsd))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.