Add a label tabel from an annotation to a GIFTI XML tree.
Source:R/gifti_xml_tools.R
giftixml_add_labeltable_from_annot.RdComputes the LabelTable XML node for the given annotation and adds it to the XML tree.
Arguments
- xmltree
an XML tree from xml2, typically the return value from
gifti_xml.- annot
an fs.annotation, the included data will be used to compute the LabelTable node