groups.in.bbox: Check which groups have at least one point inside a box.

View source: R/dti_tracks_utils.R

groups.in.bboxR Documentation

Check which groups have at least one point inside a box.

Description

Check which groups have at least one point inside a box.

Usage

groups.in.bbox(points, lengths, bbox)

Arguments

points

numeric matrix with 3 columns, the concatenated points.

lengths

integer vector with the number of points of each group.

bbox

numeric vector of length 6: c(xmin, xmax, ymin, ymax, zmin, zmax).

Value

logical vector with one entry per group.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.