guess.writable.transform.format: Determine the format of a transformation file to write.

View source: R/write_fs_transform.R

guess.writable.transform.formatR Documentation

Determine the format of a transformation file to write.

Description

Guess the transformation file format from the file name extension, for the formats this package can write.

Usage

guess.writable.transform.format(filepath)

Arguments

filepath

character string, the full path of the file to write.

Value

character string, the file format.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.