m44_to_quaternion: Compute quaternion representation of a rotation from a 4x4...

View source: R/write_fs_volume.R

m44_to_quaternionR Documentation

Compute quaternion representation of a rotation from a 4x4 rotation matrix.

Description

Compute quaternion representation of a rotation from a 4x4 rotation matrix.

Usage

m44_to_quaternion(m)

Arguments

m

the input 4x4 matrix encoding the rotation, with homogeneous column [0,0,0,1].

Value

numeric vector of length 4, the quaternion representation (qw, qx, qy, qz).


freesurferformats documentation built on July 8, 2026, 5:08 p.m.