| mghheader.crs.orientation | R Documentation |
Compute MGH volume orientation string.
mghheader.crs.orientation(header)
header |
Header of the mgh datastructure, as returned by |
character string of length 3, one uppercase letter per axis. Each of the three position is a letter from the alphabet: LRISAP?. The meaning is L for left, R for right, I for inferior, S for superior, P for posterior, A for anterior. If the direction cannot be computed, all three characters are ? for unknown. Of course, each axis (L/R, I/S, A/P) is only represented once in the string.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.