Compute data dimensions from the 'dim' field of the NIFTI (v1 or v2) header.
Source:R/nifti_common.R
nifti.datadim.from.dimfield.RdCompute data dimensions from the 'dim' field of the NIFTI (v1 or v2) header.
Arguments
- dimfield
integer vector of length 8, the
dimfield of a NIFTI v1 or v2 header, as returned byread.nifti2.headerorread.nifti1.header.
Value
integer vector of length <= 7. The lengths of the used data dimensions. The 'dim' field always has length 8, and the first entry is the number of actually used dimensions. The return value is constructed by stripping the first field and returning the used fields.
See also
Other NIFTI helper functions:
nifti.datadim.to.dimfield()
Examples
nifti.datadim.from.dimfield(c(3, 256, 256, 256, 1, 1, 1, 1))
#> [1] 256 256 256