nifti.datadim.to.dimfield: Compute NIFTI dim field for data dimension.

View source: R/nifti_common.R

nifti.datadim.to.dimfieldR Documentation

Compute NIFTI dim field for data dimension.

Description

Compute NIFTI dim field for data dimension.

Usage

nifti.datadim.to.dimfield(datadim)

Arguments

datadim

integer vector, the result of calling dim on your data. The length must be <= 7.

Value

NIFTI header dim field, an integer vector of length 8

See Also

Other NIFTI helper functions: nifti.datadim.from.dimfield()

Examples

nifti.datadim.to.dimfield(c(256, 256, 256))


freesurferformats documentation built on Sept. 8, 2026, 5:08 p.m.