Determine whether a NIFTI file uses the FreeSurfer hack.
Source:R/read_nifti1.R
nifti.file.uses.fshack.RdDetermine whether a NIFTI file uses the FreeSurfer hack.
Value
logical, whether the file header contains the FreeSurfer format hack. See read.nifti1.header for details. This function detects NIFTI v2 files, but as they cannot contain the hack, it will always return FALSE for them.
Note
Applying this function to files which are not in NIFTI format will result in an error. See nifti.file.version to determine whether a file is a NIFTI file.