Determine NIFTI file version information and whether file is a NIFTI file.
Source:R/read_nifti1.R
nifti.file.version.RdDetermine NIFTI file version information and whether file is a NIFTI file.
R/read_nifti1.R
nifti.file.version.RdDetermine NIFTI file version information and whether file is a NIFTI file.