Perform basic sanity checks on NIFTI header data. These are in no way meant to be exhaustive.
Source:R/nifti_common.R
nifti.header.check.RdPerform basic sanity checks on NIFTI header data. These are in no way meant to be exhaustive.
R/nifti_common.R
nifti.header.check.RdPerform basic sanity checks on NIFTI header data. These are in no way meant to be exhaustive.