nifti.info.from.oro.instance: Extract the header information and the data of an 'oro.nifti'...

View source: R/nifti_to_mgh.R

nifti.info.from.oro.instanceR Documentation

Extract the header information and the data of an oro.nifti instance into a plain list.

Description

Extract the header information and the data of an oro.nifti instance into a plain list.

Usage

nifti.info.from.oro.instance(nifti_img)

Arguments

nifti_img

an instance of class nifti from the oro.nifti package.

Value

named list, see nifti.info.from.file.

Note

The data scaling fields of the instance are not applied here, they are expected to be applied already: instances read by oro.nifti::readNIfTI are rescaled unless rescale_data = FALSE was used.

See Also

nifti.info.from.file


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.