nifti.resolve.filepath: Resolve the path of a NIFTI file which is given without a...

View source: R/nifti_to_mgh.R

nifti.resolve.filepathR Documentation

Resolve the path of a NIFTI file which is given without a file extension.

Description

Resolve the path of a NIFTI file which is given without a file extension.

Usage

nifti.resolve.filepath(filepath)

Arguments

filepath

character string, the path to a NIFTI file.

Value

character string, the path of an existing file. If filepath itself does not exist, the usual NIFTI file extensions are appended to it and the first existing file is returned.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.