| nifti.transform.type.name | R Documentation |
The form code is a code stored in the sform_code and/or qform_code NIFTI header fields.
nifti.transform.type.name(form_code)
form_code |
integer, the value retrieved from the |
character string, the meaning of the code. Usually this expresses to what the data will be aligned after application of the vox2ras transformation method. (The type of transformation to perform in order to achieve this alignment depends on whether the value was retrieved from the sform or the qform field and does not matter here.)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.