| nrrd.parse.field.value | R Documentation |
Converts the string value of a header field into an R value: a number for the
integer and floating point fields, a vector for the list fields, a vector or a matrix for the
vector and matrix fields (the syntax is (1,2,3), several vectors separated by
whitespace, and the value none for a missing vector), and a character vector for the
string list fields.
nrrd.parse.field.value(key, value)
key |
character string, the normalized field name, see |
value |
character string, the raw value from the header. |
the parsed value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.