nrrd.read.remainder: Read the remaining bytes of a connection.

View source: R/read_nrrd.R

nrrd.read.remainderR Documentation

Read the remaining bytes of a connection.

Description

Reads everything from the current position to the end of the file, in chunks, to keep the peak memory of the intermediate buffers bounded. This is used for the bzip2 encoding, which R cannot decompress as a stream.

Usage

nrrd.read.remainder(con)

Arguments

con

a connection opened in binary read mode.

Value

raw vector.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.