parse.mrtrix.datatype: Validate and describe the datatype entry of an MRtrix TCK/TSF...

View source: R/read_dti_tcktsf.R

parse.mrtrix.datatypeR Documentation

Validate and describe the datatype entry of an MRtrix TCK/TSF header.

Description

Validate and describe the datatype entry of an MRtrix TCK/TSF header.

Usage

parse.mrtrix.datatype(header, filepath = "")

Arguments

header

named list, the parsed header.

filepath

character string, the path of the file, used in messages only.

Value

named list with entries dsize (bytes per value) and endian ('little' or 'big').


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.