Translate RAS coordinates, as used in volumes by applying vox2ras, to surface RAS.
Source:R/mghheader.R
ras.to.surfaceras.RdTranslate RAS coordinates, as used in volumes by applying vox2ras, to surface RAS.
Usage
ras.to.surfaceras(header_cras, ras_coords, first_voxel_RAS = c(1, 1, 1))Arguments
- header_cras
an MGH header instance from which to extract the cras (center RAS), or the cras vector, i.e., a numerical vector of length 3
- ras_coords
nx3 numerical vector, the input surface RAS coordinates. Could be the vertex coordinates of an 'fs.surface' instance, or the RAS coords from a surface label.
- first_voxel_RAS
the RAS of the first voxel, see
mghheader.centervoxelRAS.from.firstvoxelRASfor details. Ignored if 'header_cras' is a vector.