| read.fs.morph | R Documentation |
Read vertex-wise brain surface data from a file. The file can be in any of the supported formats, and the format will be determined from the file extension.
read.fs.morph(filepath, format = "auto")
filepath |
string. Full path to the input file. The suffix determines the expected format as follows: ".mgz" and ".mgh" will be read with the read.fs.mgh function, all other file extensions will be read with the read.fs.curv function. |
format |
character string, the format to use. One of c("auto", "mgh", "mgz", "curv", "gii"). The default setting "auto" will determine the format from the file extension. |
data, vector of floats. The brain morphometry data, one value per vertex.
CIFTI-2 files (which are NIFTI-2 files, see read.cifti) are
refused with an error instead of being read as NIFTI morphometry data: their
payload is a matrix whose dimensions the CIFTI XML metadata describes, so the
values would come back in an order that means nothing. Use
read.fs.morph.cifti to read the morphometry data of one brain
structure, or read.cifti for the matrix itself.
Other morphometry functions:
fs.get.morph.file.ext.for.format(),
fs.get.morph.file.format.from.filename(),
read.fs.curv(),
read.fs.mgh(),
read.fs.morph.gii(),
read.fs.volume(),
read.fs.weight(),
write.fs.curv(),
write.fs.label.gii(),
write.fs.mgh(),
write.fs.morph(),
write.fs.morph.asc(),
write.fs.morph.gii(),
write.fs.morph.ni1(),
write.fs.morph.ni2(),
write.fs.morph.smp(),
write.fs.morph.txt(),
write.fs.weight(),
write.fs.weight.asc()
curvfile <- system.file("extdata", "lh.thickness",
package = "freesurferformats", mustWork = TRUE
)
ct <- read.fs.morph(curvfile)
cat(sprintf(
"Read data for %d vertices. Values: min=%f, mean=%f, max=%f.\n",
length(ct), min(ct), mean(ct), max(ct)
))
mghfile <- system.file("extdata", "lh.curv.fwhm10.fsaverage.mgz",
package = "freesurferformats", mustWork = TRUE
)
curv <- read.fs.morph(mghfile)
cat(sprintf(
"Read data for %d vertices. Values: min=%f, mean=%f, max=%f.\n",
length(ct), min(ct), mean(ct), max(ct)
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.