Read Brainvoyager vertex-wise statistical surface data from SMP file.
Source:R/read_fs_curv.R
read.fs.morph.bvsmp.RdRead Brainvoyager vertex-wise statistical surface data from SMP file.
Arguments
- filepath
character string, path to file in Brainvoyager SMP file format. Alternatively, a 'bvsmp' instance read with
read.smp.brainvoyager.- map_index
positive integer or character string, the surface value map to load (an SMP file can contain several values per vertex, i.e., several surface maps). If an integer, interpreted as the index of the map. If a character string, as the name of the map.