View source: R/read_fs_surface.R
| read.fs.surface.asc | R Documentation |
Read FreeSurfer ASCII format surface.
read.fs.surface.asc(filepath, with_values = TRUE, header_numlines = 2L)
filepath |
string. Full path to the input surface file in ASCII surface format. |
with_values |
logical, whether to read per-vertex and per-face values. |
header_numlines |
scalar positive integer, the number of header lines. |
named list. The list has the following named entries: "vertices": nx3 double matrix, where n is the number of vertices. Each row contains the x,y,z coordinates of a single vertex. "faces": nx3 integer matrix. Each row contains the vertex indices of the 3 vertices defining the face. WARNING: The indices are returned starting with index 1 (as used in GNU R). Keep in mind that you need to adjust the index (by substracting 1) to compare with data from other software.
This is also known as srf format.
Other mesh functions:
faces.quad.to.tris(),
read.fs.surface(),
read.fs.surface.bvsrf(),
read.fs.surface.geo(),
read.fs.surface.gii(),
read.fs.surface.ico(),
read.fs.surface.obj(),
read.fs.surface.off(),
read.fs.surface.ply(),
read.fs.surface.vtk(),
read.mesh.brainvoyager(),
read_nisurface(),
read_nisurfacefile(),
write.fs.surface(),
write.fs.surface.asc(),
write.fs.surface.byu(),
write.fs.surface.gii(),
write.fs.surface.mz3(),
write.fs.surface.vtk()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.