Read surface mesh in mz3 format, used by Surf-Ice.
Source:R/read_fs_surface.R
read.fs.surface.mz3.RdThe mz3 format is a binary file format that can store a mesh (vertices and faces), and optionally per-vertex colors or scalars.
R/read_fs_surface.R
read.fs.surface.mz3.RdThe mz3 format is a binary file format that can store a mesh (vertices and faces), and optionally per-vertex colors or scalars.