Read morphometry data in weight format (aka w files). A weight format file contains morphometry data for a set of vertices, defined by their index in a surface. This can be only a subset of the surface vertices.
Value
the indices and weight data, as a named list. Entries: "vertex_indices": vector of n vertex indices. They are stored zero-based in the file, but are returned one-based (R-style). "value": double vector of length n, the morphometry data for the vertices. The data can be whatever you want.
See also
Other morphometry functions:
fs.get.morph.file.ext.for.format(),
fs.get.morph.file.format.from.filename(),
read.fs.curv(),
read.fs.mgh(),
read.fs.morph(),
read.fs.morph.gii(),
read.fs.volume(),
write.fs.curv(),
write.fs.label.gii(),
write.fs.mgh(),
write.fs.morph(),
write.fs.morph.asc(),
write.fs.morph.gii(),
write.fs.morph.ni1(),
write.fs.morph.ni2(),
write.fs.morph.smp(),
write.fs.morph.txt(),
write.fs.weight(),
write.fs.weight.asc()