Read ASCII version of FreeSurfer weight file. Called by read.fs.weight if parameter format is set to 'asc'.
read.fs.weight.asc(filepath)the indices and weight data, as a named list. Entries: "vertex_indices": vector of n vertex indices. They are stored zero-based in the file, but are returned one-based (R-style). "value": double vector of length n, the morphometry data for the vertices. The data can be whatever you want.
string. Full path to the input weight file, must be in ASCII weight format.