read.mrtrix.header: Read the ASCII header of an MRtrix TCK/TSF file.

View source: R/read_dti_tcktsf.R

read.mrtrix.headerR Documentation

Read the ASCII header of an MRtrix TCK/TSF file.

Description

Reads lines up to and including the terminating 'END' line. The number of header lines is not limited, headers of real files contain a variable number of entries (command history, comments, ROI specifications).

Usage

read.mrtrix.header(filepath)

Arguments

filepath

character string, path to the file.

Value

named list with entries lines (the raw header lines), gzipped (logical) and header (the parsed key-value pairs).


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.