read.nifti2.header: Read NIFTI v2 header from file.

View source: R/read_nifti2.R

read.nifti2.headerR Documentation

Read NIFTI v2 header from file.

Description

Read NIFTI v2 header from file.

Usage

read.nifti2.header(filepath)

Arguments

filepath

path to a NIFTI v2 file.

Value

named list with NIFTI 2 header fields. The header extensions, if the file has any, are returned in the field extensions, a list in which each entry is one header extension as created by nifti2.extension (i.e., a list with the entries 'ecode' and 'content'). CIFTI2 files store their XML metadata in such an extension, see nifti2.get.extension.

See Also

write.nifti2


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.