Skip to contents

Adapt spatial transformation matrix for 0-based indices.

Usage

sm1to0(tf_matrix)

Arguments

tf_matrix

4x4 numerical matrix, the input spatial transformation matrix, suitable for 1-based indices.

Value

4x4 numerical matrix, adapted spatial transformation matrix, suitable for 0-based indices.