sub-sub-.fs.tracts: Access a single tract of an fs.tracts instance.

[[.fs.tractsR Documentation

Access a single tract of an fs.tracts instance.

Description

For TCK data (see read.dti.tck), a tract is an n x 3 numeric matrix of coordinates. For TRK data (see read.dti.trk), a tract is a named list with the entries coords (n x 3 matrix), num_points (integer), scalars (n x n_scalars matrix or NULL) and properties (numeric vector or NULL).

This returns a copy of the requested tract, the data is stored in a single matrix internally.

Usage

## S3 method for class 'fs.tracts'
x[[i]]

Arguments

x

an fs.tracts instance.

i

positive integer, the index of the tract to retrieve.

Value

the tract, see the description.

Examples

## Not run: 
tck <- read.dti.tck("brain.tck");
first_tract_coords <- tck$tracks[[1]];

## End(Not run)


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.