transform.bbox: Transform a bounding box with an affine.

View source: R/trackvis_affine.R

transform.bboxR Documentation

Transform a bounding box with an affine.

Description

Returns the axis-aligned bounding box of the transformed box. For a linear transformation the extremes of the image of a box are attained at its corners, so transforming the 8 corners gives the exact bounding box of the transformed data.

Usage

## S3 method for class 'bbox'
transform(bbox, affine)

Arguments

bbox

numeric vector of length 6, c(xmin, xmax, ymin, ymax, zmin, zmax).

affine

4x4 numeric matrix.

Value

numeric vector of length 6.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.