transform.descriptor.path: Get the file path recorded in a volume descriptor.

View source: R/transforms_convert.R

transform.descriptor.pathR Documentation

Get the file path recorded in a volume descriptor.

Description

Get the file path recorded in a volume descriptor.

Usage

## S3 method for class 'descriptor.path'
transform(descriptor)

Arguments

descriptor

NULL or a volume descriptor, see volume.descriptor.

Value

NULL or character string.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.