transform.geometry.for.side: Determine the volume geometry of one side of a...

View source: R/transforms_convert.R

transform.geometry.for.sideR Documentation

Determine the volume geometry of one side of a transformation.

Description

Use the geometry recorded in the transformation itself if it is available, and the volume passed by the caller otherwise.

Usage

## S3 method for class 'geometry.for.side'
transform(tf, side, volume = NULL)

Arguments

tf

an fs.transform instance.

side

character string, either 'src' or 'dst'.

volume

NULL or a volume, see volume.geometry.

Value

NULL or a geometry list as returned by volume.geometry.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.