trk.track.iterator: Create an iterator over the tracts of a TRK file.

View source: R/dti_tracks_utils.R

trk.track.iteratorR Documentation

Create an iterator over the tracts of a TRK file.

Description

Create an iterator over the tracts of a TRK file.

Usage

trk.track.iterator(filepath, skip_tracks = 0L, bbox = NULL)

Arguments

filepath

character string, path to the file.

skip_tracks

integer, the number of tracts to skip.

bbox

numeric vector of length 6 or NULL, a bounding box, see read.dti.tck.

Value

the iterator environment.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.