Compute Euclidean distance from all mesh vertices to given point.
Source:R/surface_dist.R
vertexdists.to.point.RdCompute Euclidean distance from all mesh vertices to given point.
See also
Other Euclidean distance util functions:
closest.vert.to.point(),
vertex.euclid.dist()