vtk.as.indices: Convert values that are used as indices to integers.

View source: R/vtk_legacy.R

vtk.as.indicesR Documentation

Convert values that are used as indices to integers.

Description

Convert values that are used as indices to integers.

Usage

vtk.as.indices(values, filepath)

Arguments

values

numeric vector, the values to convert.

filepath

character string, the file the values were read from.

Value

integer vector.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.