vtk.check.triangles: Check that all cells of the requested type are triangles.

View source: R/vtk_legacy.R

vtk.check.trianglesR Documentation

Check that all cells of the requested type are triangles.

Description

Check that all cells of the requested type are triangles.

Usage

vtk.check.triangles(cells, filepath)

Arguments

cells

list of integer vectors, as returned by vtk.parse.cell.section.

filepath

character string, the file the cells were read from.

Value

NULL, invisibly. Stops if a cell is not a triangle.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.