vtk.next.section: Read the next section header line of a VTK legacy file.

View source: R/vtk_legacy.R

vtk.next.sectionR Documentation

Read the next section header line of a VTK legacy file.

Description

Read the next section header line of a VTK legacy file.

Usage

vtk.next.section(reader)

Arguments

reader

an environment as returned by vtk.reader.new.

Value

named list with the entries 'keyword' (character, e.g. 'POLYGONS') and 'args' (character vector, the remaining tokens of the line), or NULL at the end of the file.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.