vtk.parse.count: Read a non-negative integer from a VTK section header.

View source: R/vtk_legacy.R

vtk.parse.countR Documentation

Read a non-negative integer from a VTK section header.

Description

Read a non-negative integer from a VTK section header.

Usage

vtk.parse.count(value, filepath, what)

Arguments

value

character string, the token to parse.

filepath

character string, the file being read, for error messages.

what

character string, a description of the value, for error messages.

Value

single integer.


freesurferformats documentation built on Sept. 25, 2026, 1:07 a.m.