| vtk.reader.numbers | R Documentation |
Read numeric values from a binary VTK legacy file.
vtk.reader.numbers(reader, num_values, type_info)
reader |
an environment as returned by |
num_values |
single non-negative integer, the number of values to read. |
type_info |
named list, the result of |
numeric or integer vector of length num_values.
Legacy VTK binary data is always big endian, the format has no way of expressing a different byte order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.