write.fs.annot.gii: Write annotation to GIFTI file.

View source: R/write_fs_annot.R

write.fs.annot.giiR Documentation

Write annotation to GIFTI file.

Description

Write an annotation to a GIFTI XML file.

Usage

write.fs.annot.gii(filepath, annot)

Arguments

filepath

string, path to the output file.

annot

fs.annot instance, an annotation.

Note

This function does not write a GIFTI file that is valid according to the specification: it stores extra color data in the Label nodes, and there is more than one Label in the LabelTable node.

See Also

Other atlas functions: atlas.from.lut.and.csv(), colortable.from.annot(), read.fs.annot(), read.fs.colortable(), write.atlas.to.lut.and.csv(), write.fs.annot(), write.fs.colortable()

Other gifti writers: write.fs.label.gii(), write.fs.morph.gii(), write.fs.surface.gii()

Examples

## Not run: 
# Load annotation
annot_file <- system.file("extdata", "lh.aparc.annot.gz",
  package = "freesurferformats",
  mustWork = TRUE
)
annot <- read.fs.annot(annot_file)
# New method: write the annotation instance:
write.fs.annot.gii(tempfile(fileext = ".annot"), annot)

## End(Not run)


freesurferformats documentation built on Sept. 8, 2026, 5:08 p.m.