Write vertex-wise brain surface data to a file in FreeSurfer ascii 'curv' format.
Arguments
- filepath
string. Full path to the output curv file. If it ends with ".gz", the file is written in gzipped format. Note that this is not common, and that other software may not handle this transparently.
- data
vector of doubles. The brain morphometry data to write, one value per vertex.
- coords
optional, nx3 matrix of x,y,z coordinates, one row per vertex in 'data'. If
NULL, all zeroes will be written instead.
See also
Other morphometry functions:
fs.get.morph.file.ext.for.format(),
fs.get.morph.file.format.from.filename(),
read.fs.curv(),
read.fs.mgh(),
read.fs.morph(),
read.fs.morph.gii(),
read.fs.volume(),
read.fs.weight(),
write.fs.curv(),
write.fs.label.gii(),
write.fs.mgh(),
write.fs.morph(),
write.fs.morph.gii(),
write.fs.morph.ni1(),
write.fs.morph.ni2(),
write.fs.morph.smp(),
write.fs.morph.txt(),
write.fs.weight(),
write.fs.weight.asc()