| write.nifti1.data.internal | R Documentation |
Write the voxel data of a NIFTI v1 file to a connection.
write.nifti1.data.internal(fh, niidata, niiheader)
fh |
connection to write to. |
niidata |
array of numeric data, or |
niiheader |
named list, a valid NIFTI v1 header that describes the data. |
the data that was written, after conversion to the data type stated in the header, or NULL if niidata
was NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.