| write.nifti2 | R Documentation |
Write header and data to a file in NIFTI v2 format.
write.nifti2(filepath, niidata, niiheader = NULL, extensions = NULL)
filepath |
the file to write. The extension should be '.nii' or '.nii.gz'. |
niidata |
array of numeric or integer data, with up to 7 dimensions. Will be written to the file with the datatype and bitpix specified in the 'niiheader' argument. |
niiheader |
an optional NIFTI v2 header that is suitable for the passed 'niidata'. If not given, one will be generated with |
extensions |
optional list of NIFTI v2 header extensions to write between the header and the data, each
created with |
read.nifti2.header, nifti2.get.extension
Other nifti2 writers:
write.fs.morph.ni2()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.