The readers document a label table with the column names 'Key', 'Red', 'Green', 'Blue', 'Alpha' and 'Label'; keep that spelling (and the column order) for the user-facing functions, while the internal representation uses lower case column names and also stores the optional label coordinates.
.cifti.label.table.for.users(labels)a data.frame with the columns 'Key', 'Red', 'Green', 'Blue', 'Alpha' and 'Label'.
a data.frame as returned by cifti.label.table.