Learn R Programming

freesurferformats (version 1.1.0)

analyze.dtype.info: Compute the R data type and the number of bytes per value for an ANALYZE data type.

Description

Compute the R data type and the number of bytes per value for an ANALYZE data type.

Usage

analyze.dtype.info(analyzeheader, filepath = NULL)

Value

named list with the entries datatype and bitpix (the data type fields to use for reading the data, which may differ from the values in the file if the file contradicts itself), num_bytes (the number of bytes per value) and r_dtype (the R type to read the values as).

Arguments

analyzeheader

named list, an ANALYZE 7.5 header as returned by read.analyze.header.

filepath

character string, the path of the file the header was read from. Only used for warning and error messages.