Compute the R data type and the number of bytes per value for an ANALYZE data type.
analyze.dtype.info(analyzeheader, filepath = NULL)named list with the entries datatype and bitpix (the data type fields to use for reading the data,
which may differ from the values in the file if the file contradicts itself), num_bytes (the number of bytes
per value) and r_dtype (the R type to read the values as).
named list, an ANALYZE 7.5 header as returned by read.analyze.header.
character string, the path of the file the header was read from. Only used for warning and error messages.