| analyze.read.header.internal | R Documentation |
Read ANALYZE 7.5 header from file.
analyze.read.header.internal(filepath, little_endian = TRUE)
filepath |
character string, the path to the |
little_endian |
logical, leave this alone. The endianness is detected automatically, and messing with this parameter only makes the detection report a wrong endianness for a file of the other one. |
named list, the ANALYZE 7.5 header. See read.analyze.header.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.