| as.list.fs.tracts | R Documentation |
Converts to the classic representation as a list with one
entry per tract. This is convenient for interacting with code that expects
a plain list, but note that it materializes one R object per tract and is
therefore much more expensive in both memory and time. Prefer [[
for accessing individual tracts.
## S3 method for class 'fs.tracts'
as.list(x, ...)
x |
an |
... |
ignored. |
list with one entry per tract.
## Not run:
tck <- read.dti.tck("brain.tck");
tracts_list <- as.list(tck$tracks);
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.