as.list.fs.tracts: Convert an fs.tracts instance to a plain list of tracts.
Description
Converts to the classic representation as a list with one
entry per tract. This is convenient for interacting with code that expects
a plain list, but note that it materializes one R object per tract and is
therefore much more expensive in both memory and time. Prefer [[
for accessing individual tracts.