Learn R Programming

freesurferformats (version 1.1.0)

as.tsf.scalars: Convert scalar values for streamlines to a list of vectors.

Description

Normalizes the several input forms accepted by write.dti.tsf to a list of numeric vectors, one per streamline, and checks the lengths for consistency.

Usage

as.tsf.scalars(tracts, lengths = NULL)

Value

named list with entries values (list of numeric vectors) and lengths (integer vector).

Arguments

tracts

the input, see write.dti.tsf.

lengths

integer vector or NULL, the number of values per streamline. Only used when tracts is a plain vector of values.