Normalizes the several input forms accepted by
write.dti.tsf to a list of numeric vectors, one per
streamline, and checks the lengths for consistency.
as.tsf.scalars(tracts, lengths = NULL)named list with entries values (list of numeric vectors) and
lengths (integer vector).
the input, see write.dti.tsf.
integer vector or NULL, the number of values per streamline.
Only used when tracts is a plain vector of values.