Learn R Programming

freesurferformats (version 1.1.0)

axcodes2ornt: Convert axis codes to an orientation array.

Description

Convert axis codes to an orientation array.

Usage

axcodes2ornt(axcodes)

Value

numeric matrix with 3 rows and 2 columns, see io.orientation.

Arguments

axcodes

character vector with one code per input axis, e.g. c('L','P','S') for a file whose first voxel axis points left.