powered by
Convert axis codes to an orientation array.
axcodes2ornt(axcodes)
numeric matrix with 3 rows and 2 columns, see io.orientation.
io.orientation
character vector with one code per input axis, e.g. c('L','P','S') for a file whose first voxel axis points left.
c('L','P','S')