Learn R Programming

freesurferformats (version 1.0.2)

check_all_finite: Check that a numeric vector or matrix contains only finite values.

Description

Stops with an error if the input contains NA, NaN, or Inf values.

Usage

check_all_finite(x, label = "data")

Value

TRUE (invisibly) if all values are finite. Stops otherwise.

Arguments

x

a numeric vector or matrix.

label

character string, a human-readable label for the data (used in the error message).