Learn R Programming

freesurferformats (version 1.1.0)

cifti.annot.list: Accept the input forms of a set of annotations.

Description

Accept the input forms of a set of annotations.

Usage

cifti.annot.list(annots, structure = NULL)

Value

a named list of fs.annot instances, named by canonical brain structure name.

Arguments

annots

an fs.annot instance or a named list of them.

structure

character string or NULL, the brain structure of a single annotation.