View source: R/cifti_parcels.R
| cifti.annot.parcels | R Documentation |
Collect the vertices of each region of an annotation.
cifti.annot.parcels(annot, structure_name, default_label_name = "unknown")
annot |
an |
structure_name |
character string, the brain structure of the annotation, used in error messages. |
default_label_name |
character string, the name for vertices without a region name. |
a named list of integer vectors, one entry per region that contains at least one vertex: the 0-based vertex indices of the region, in ascending order. The entries are ordered like the label table of the annotation (the atlas order).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.