Learn R Programming

freesurferformats (version 1.1.0)

cifti.annot.parcels: Collect the vertices of each region of an annotation.

Description

Collect the vertices of each region of an annotation.

Usage

cifti.annot.parcels(annot, structure_name, default_label_name = "unknown")

Value

a named list of integer vectors, one entry per region that contains at least one vertex: the 0-based vertex indices of the region, in ascending order. The entries are ordered like the label table of the annotation (the atlas order).

Arguments

annot

an fs.annot instance, see read.fs.annot.

structure_name

character string, the brain structure of the annotation, used in error messages.

default_label_name

character string, the name for vertices without a region name.