| cifti.array.with.new.first.dim | R Documentation |
Create an array like the input, with a different first dimension.
cifti.array.with.new.first.dim(data, first_dim_size)
data |
the array, its first dimension is the one that is replaced. |
first_dim_size |
integer, the size of the new first dimension. |
an array of NA of the data type of data, with the new first
dimension and all other dimensions of data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.