cifti.axis.for.maps: Build the axis for a set of maps.
Description
Build the axis for a set of maps.
Usage
cifti.axis.for.maps(map_names, nx, template_map_axis = NULL)
Value
an axis, see cifti.axis.scalars.
Arguments
- map_names
character vector or NULL, the map names.
- nx
integer, the number of maps in the data.
- template_map_axis
the axis of the template file for this dimension, or NULL.
If it has as many maps as the data, its map names and the per-map metadata (e.g. the
palette information) are kept.