View source: R/write_cifti_axes.R
| cifti.axis.parcels | R Documentation |
A parcel axis describes the parcels of a parcellated matrix dimension (the
mapping of .pscalar, .ptseries, .pconn and the second dimension of .pdconn).
As for brain models, the index of a parcel is its position in the list.
cifti.axis.parcels(parcels, surfaces = NULL, volume = NULL)
parcels |
list of parcels, as created by |
surfaces |
named integer vector or |
volume |
a volume, see |
a named list with the entries 'type', 'parcels', 'surfaces' and 'volumes', an
axis to be passed to cifti.header.from.axes or
write.cifti.
Other cifti functions:
cifti.axis.brain.models(),
cifti.axis.from.template(),
cifti.axis.labels(),
cifti.axis.parcels.from.annot(),
cifti.axis.scalars(),
cifti.axis.series(),
cifti.brain.model.surface(),
cifti.brain.model.volume(),
cifti.dim.labels(),
cifti.file.type.for.axes(),
cifti.grayordinates(),
cifti.header.from.axes(),
cifti.label.table(),
cifti.parcel(),
cifti.parcels(),
cifti.series.info(),
cifti.structure.data(),
cifti.structures(),
cifti.volume(),
print.fs.cifti(),
print.fs.cifti.data(),
print.fs.connectome(),
read.cifti(),
read.cifti.header(),
read.cifti.rows(),
read.fs.connectome.cifti(),
write.cifti(),
write.fs.connectome.cifti(),
write.fs.morph.cifti(),
write.fs.parcellated.cifti(),
write.fs.parcellation.cifti(),
write.fs.series.cifti()
axis <- cifti.axis.parcels(list(
cifti.parcel("PARCEL_A", list(CORTEX_LEFT = 0:2)),
cifti.parcel("PARCEL_B", list(CORTEX_LEFT = 3:5))))
length(axis$parcels)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.