Learn R Programming

freesurferformats (version 1.1.0)

cifti.axis.parcels: Create a CIFTI-2 axis for parcels.

Description

A parcel axis describes the parcels of a parcellated matrix dimension (the mapping of .pscalar, .ptseries, .pconn and the second dimension of .pdconn). As for brain models, the index of a parcel is its position in the list.

Usage

cifti.axis.parcels(parcels, surfaces = NULL, volume = NULL)

Value

a named list with the entries 'type', 'parcels', 'surfaces' and 'volumes', an axis to be passed to cifti.header.from.axes or write.cifti.

Arguments

parcels

list of parcels, as created by cifti.parcel.

surfaces

named integer vector or NULL, the number of vertices of the complete surfaces the parcels refer to, see cifti.axis.brain.models. Unlike Connectome Workbench, which writes them, this is optional here as well.

volume

a volume, see cifti.volume, for parcels that consist of volume voxels, or NULL.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.axis.series(), cifti.brain.model.surface(), cifti.brain.model.volume(), cifti.dim.labels(), cifti.file.type.for.axes(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.series.info(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

Run this code
axis <- cifti.axis.parcels(list(
  cifti.parcel("PARCEL_A", list(CORTEX_LEFT = 0:2)),
  cifti.parcel("PARCEL_B", list(CORTEX_LEFT = 3:5))))
length(axis$parcels)

Run the code above in your browser using DataLab