A scalars axis holds a set of maps (e.g. the myelin map and the cortical
thickness of a subject in one .dscalar file), a labels axis holds a set of label maps
(one per parcellation in a .dlabel file). Both are described by their map names; a
labels axis can additionally have a label table per map, which maps the integer label
keys in the data to names and colors.
cifti.axis.scalars(names = NULL, metadata = NULL)a named list with the entries 'type' and 'named_maps', an axis to be passed to
cifti.header.from.axes or write.cifti.
character vector or NULL, the map names. The number of maps is the number
of names, so this has to be given (use empty strings for unnamed maps).
list of metadata lists or NULL, one per map. Each metadata list is a
named list of character strings, as returned for a map by read.cifti.header.
This is used for the palette information that Connectome Workbench stores per map.
Other cifti functions:
cifti.axis.brain.models(),
cifti.axis.from.template(),
cifti.axis.labels(),
cifti.axis.parcels(),
cifti.axis.parcels.from.annot(),
cifti.axis.series(),
cifti.brain.model.surface(),
cifti.brain.model.volume(),
cifti.dim.labels(),
cifti.file.type.for.axes(),
cifti.grayordinates(),
cifti.header.from.axes(),
cifti.label.table(),
cifti.parcel(),
cifti.parcels(),
cifti.series.info(),
cifti.structure.data(),
cifti.structures(),
cifti.volume(),
print.fs.cifti(),
print.fs.cifti.data(),
print.fs.connectome(),
read.cifti(),
read.cifti.header(),
read.cifti.rows(),
read.fs.connectome.cifti(),
write.cifti(),
write.fs.connectome.cifti(),
write.fs.morph.cifti(),
write.fs.parcellated.cifti(),
write.fs.parcellation.cifti(),
write.fs.series.cifti()
axis <- cifti.axis.scalars(c("thickness", "area"))
length(axis$named_maps)
Run the code above in your browser using DataLab