cifti.axis.surface.sizes: Get the surface sizes of an axis as a named vector.
Description
Get the surface sizes of an axis as a named vector.
Usage
cifti.axis.surface.sizes(axis)
Value
named integer vector or NULL, the number of vertices per structure, see
cifti.axis.brain.models.
Arguments
- axis
an axis of type 'CIFTI_INDEX_TYPE_BRAIN_MODELS'.