| cifti.brainordinate.dims | R Documentation |
A single MatrixIndicesMap element can apply to both matrix
dimensions (this is the case for connectome files like .dconn and
.pconn), so the dimensions have to be counted, not the mapping elements.
cifti.brainordinate.dims(cii)
cii |
an |
integer vector, the dimensions that contain brain models (usually one,
two for a file like .dconn).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.