Learn R Programming

freesurferformats (version 1.1.0)

cifti.brainordinate.dims: Get all matrix dimensions of a CIFTI-2 file that hold brain models.

Description

A single MatrixIndicesMap element can apply to both matrix dimensions (this is the case for connectome files like .dconn and .pconn), so the dimensions have to be counted, not the mapping elements.

Usage

cifti.brainordinate.dims(cii)

Value

integer vector, the dimensions that contain brain models (usually one, two for a file like .dconn).

Arguments

cii

an fs.cifti instance, see read.cifti.header.