| cifti.check.axes | R Documentation |
Check a list of axes and name the dimensions.
cifti.check.axes(axes)
axes |
list of axes, see |
the list, with the axes named by their matrix dimension.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.