Learn R Programming

freesurferformats (version 1.1.0)

cifti.check.axes: Check a list of axes and name the dimensions.

Description

Check a list of axes and name the dimensions.

Usage

cifti.check.axes(axes)

Value

the list, with the axes named by their matrix dimension.

Arguments

axes

list of axes, see cifti.header.from.axes.