powered by
Check a list of axes and name the dimensions.
cifti.check.axes(axes)
the list, with the axes named by their matrix dimension.
list of axes, see cifti.header.from.axes.
cifti.header.from.axes