| cifti.check.data.for.axes | R Documentation |
Check and prepare the data for a set of axes.
cifti.check.data.for.axes(data, axes)
data |
the data, see |
axes |
list of axes, see |
the data as an array with the dimensions of the axes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.