Learn R Programming

freesurferformats (version 1.1.0)

cifti.check.data.for.axes: Check and prepare the data for a set of axes.

Description

Check and prepare the data for a set of axes.

Usage

cifti.check.data.for.axes(data, axes)

Value

the data as an array with the dimensions of the axes.

Arguments

data

the data, see write.cifti.

axes

list of axes, see cifti.header.from.axes.