View source: R/write_cifti_fs.R
| cifti.data.for.all.vertices | R Documentation |
Assemble the data values of all vertices for a file without a template.
cifti.data.for.all.vertices(data, structures, what = "data")
data |
the data, see |
structures |
character vector, the canonical structure names, in file order. |
what |
character string, a description of the data, used in error messages. |
a matrix with one row per vertex (structures one after the other) and one column per map.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.