Learn R Programming

freesurferformats (version 1.1.0)

cifti.data.for.all.vertices: Assemble the data values of all vertices for a file without a template.

Description

Assemble the data values of all vertices for a file without a template.

Usage

cifti.data.for.all.vertices(data, structures, what = "data")

Value

a matrix with one row per vertex (structures one after the other) and one column per map.

Arguments

data

the data, see write.fs.morph.cifti.

structures

character vector, the canonical structure names, in file order.

what

character string, a description of the data, used in error messages.