Assemble the data values of all vertices for a file without a template.
cifti.data.for.all.vertices(data, structures, what = "data")a matrix with one row per vertex (structures one after the other) and one column per map.
the data, see write.fs.morph.cifti.
character vector, the canonical structure names, in file order.
character string, a description of the data, used in error messages.