View source: R/write_cifti_fs.R
| cifti.data.for.grayordinates | R Documentation |
Select the data values of the grayordinates of a file.
cifti.data.for.grayordinates(data, structures, index_table, what)
data |
the data, see |
structures |
character vector, the canonical structure names, in file order. |
index_table |
the brainordinate table, see |
what |
character string, a description of the data, used in error messages. |
a matrix with one row per grayordinate (in file order) and one column per map.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.