Learn R Programming

freesurferformats (version 1.1.0)

cifti.data.for.grayordinates: Select the data values of the grayordinates of a file.

Description

Select the data values of the grayordinates of a file.

Usage

cifti.data.for.grayordinates(data, structures, index_table, what)

Value

a matrix with one row per grayordinate (in file order) and one column per map.

Arguments

data

the data, see write.fs.morph.cifti.

structures

character vector, the canonical structure names, in file order.

index_table

the brainordinate table, see cifti.grayordinates.

what

character string, a description of the data, used in error messages.