Select the data values of the grayordinates of a file.
cifti.data.for.grayordinates(data, structures, index_table, what)a matrix with one row per grayordinate (in file order) and one column per map.
the data, see write.fs.morph.cifti.
character vector, the canonical structure names, in file order.
the brainordinate table, see cifti.grayordinates.
character string, a description of the data, used in error messages.