View source: R/write_cifti_fs.R
| cifti.data.per.structure | R Documentation |
Get the per-structure data of one structure.
cifti.data.per.structure(data, structure_name, what)
data |
the data, see |
structure_name |
character string, the canonical structure name. |
what |
character string, a description of the data, used in error messages. |
a matrix with one row per vertex of the complete surface and one column per map.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.