Learn R Programming

freesurferformats (version 1.1.0)

cifti.data.per.structure: Get the per-structure data of one structure.

Description

Get the per-structure data of one structure.

Usage

cifti.data.per.structure(data, structure_name, what)

Value

a matrix with one row per vertex of the complete surface and one column per map.

Arguments

data

the data, see write.fs.morph.cifti.

structure_name

character string, the canonical structure name.

what

character string, a description of the data, used in error messages.