cifti.data.surface.size: The number of vertices of the surface of one structure.
Description
The number of vertices of the surface of one structure.
Usage
cifti.data.surface.size(data, structure_name)
Value
integer, the number of vertices.
Arguments
- data
the data, see write.fs.morph.cifti.
- structure_name
character string, the canonical structure name.