| cifti.dim.to.front | R Documentation |
Move one dimension of an array to the front.
cifti.dim.to.front(data, dim)
data |
the array. |
dim |
integer, the dimension to move, counted from 0 (CIFTI style). |
the array with the requested dimension first, and all other dimensions in their original order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.