Learn R Programming

freesurferformats (version 1.1.0)

cifti.dim.to.front: Move one dimension of an array to the front.

Description

Move one dimension of an array to the front.

Usage

cifti.dim.to.front(data, dim)

Value

the array with the requested dimension first, and all other dimensions in their original order.

Arguments

data

the array.

dim

integer, the dimension to move, counted from 0 (CIFTI style).