View source: R/read_cifti_header.R
| cifti.file.looks.like.cifti1 | R Documentation |
This is a heuristic used to produce a helpful error message when a CIFTI-1 file is passed to the reader: CIFTI-1 files are NIFTI-1 files (not NIFTI-2), and this function searches the first bytes of the file for the string 'CIFTI'. It is not used for any other purpose.
cifti.file.looks.like.cifti1(filepath)
filepath |
character string, the path to a CIFTI-2 file (usually one of
|
logical, whether the file looks like a CIFTI-1 file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.