Learn R Programming

freesurferformats (version 1.1.0)

cifti.file.type.for.axes: Get the standard CIFTI-2 file type for a set of axes.

Description

Look up the file type that the format defines for the combination of matrix index types of the axes, see cifti.file.types.

Usage

cifti.file.type.for.axes(axes)

Value

a one row data.frame, see cifti.file.types, or a row with intent_code = 3000 ('ConnUnknown') and empty file name extension for a combination that the standard does not define.

Arguments

axes

list of axes, see cifti.header.from.axes.

See Also

Other cifti functions: cifti.axis.brain.models(), cifti.axis.from.template(), cifti.axis.labels(), cifti.axis.parcels(), cifti.axis.parcels.from.annot(), cifti.axis.scalars(), cifti.axis.series(), cifti.brain.model.surface(), cifti.brain.model.volume(), cifti.dim.labels(), cifti.grayordinates(), cifti.header.from.axes(), cifti.label.table(), cifti.parcel(), cifti.parcels(), cifti.series.info(), cifti.structure.data(), cifti.structures(), cifti.volume(), print.fs.cifti(), print.fs.cifti.data(), print.fs.connectome(), read.cifti(), read.cifti.header(), read.cifti.rows(), read.fs.connectome.cifti(), write.cifti(), write.fs.connectome.cifti(), write.fs.morph.cifti(), write.fs.parcellated.cifti(), write.fs.parcellation.cifti(), write.fs.series.cifti()

Examples

Run this code
axis_brain <- cifti.axis.brain.models(list(cifti.brain.model.surface("lh", 10L)))
type <- cifti.file.type.for.axes(list(cifti.axis.scalars("m"), axis_brain))
type$extension

Run the code above in your browser using DataLab