View source: R/write_cifti_connectome.R
| cifti.file.type.for.extension | R Documentation |
The CIFTI-2 file type a file name names.
cifti.file.type.for.extension(filepath)
filepath |
character string, a file name. |
character string, the standard file name extension the name ends with (e.g. '.pscalar.nii'), or the empty string if it does not end with one of them.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.