cifti.file.type.for.extension: The CIFTI-2 file type a file name names.
Description
The CIFTI-2 file type a file name names.
Usage
cifti.file.type.for.extension(filepath)
Value
character string, the standard file name extension the name ends with (e.g.
'.pscalar.nii'), or the empty string if it does not end with one of them.
Arguments
- filepath
character string, a file name.