| cifti.grayordinates.for.model | R Documentation |
Expand one brain model entry into a brainordinate table.
cifti.grayordinates.for.model(map, model)
map |
the indices map the brain model belongs to, see
|
model |
one brain model entry of the map. |
a data.frame, see cifti.grayordinates.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.