cifti.grayordinates.for.model: Expand one brain model entry into a brainordinate table.
Description
Expand one brain model entry into a brainordinate table.
Usage
cifti.grayordinates.for.model(map, model)
Value
a data.frame, see cifti.grayordinates.
Arguments
- map
the indices map the brain model belongs to, see
cifti.map.for.dim.
- model
one brain model entry of the map.