View source: R/read_cifti_header.R
| cifti.map.for.dim | R Documentation |
Get the single MatrixIndicesMap (mapping) that describes the
given matrix dimension. A CIFTI-2 file can have several mappings, and one
mapping can apply to several dimensions (this is the case for connectome
files like .dconn and .pconn).
cifti.map.for.dim(cii, dim)
cii |
an |
dim |
integer, the matrix dimension to get the brain models for. CIFTI-2
files have two dimensions, so this is usually 0 (Workbench calls it the ROW
dimension) or 1 (the COLUMN dimension). See
|
the indices map, a named list, see read.cifti.header.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.