Learn R Programming

freesurferformats (version 1.1.0)

cifti.map.for.dim: Get the CIFTI indices map for a matrix dimension.

Description

Get the single MatrixIndicesMap (mapping) that describes the given matrix dimension. A CIFTI-2 file can have several mappings, and one mapping can apply to several dimensions (this is the case for connectome files like .dconn and .pconn).

Usage

cifti.map.for.dim(cii, dim)

Value

the indices map, a named list, see read.cifti.header.

Arguments

cii

an fs.cifti instance, see read.cifti.header.

dim

integer, the matrix dimension to get the brain models for. CIFTI-2 files have two dimensions, so this is usually 0 (Workbench calls it the ROW dimension) or 1 (the COLUMN dimension). See read.cifti.header for details on the dimensions.