| cifti.map.name | R Documentation |
Get the name of one named map of a CIFTI-2 file.
cifti.map.name(cii, dim, map = 1L)
cii |
an |
dim |
integer, the matrix dimension that holds the named maps. |
map |
integer, the number of the map (1-based). |
character string, the map name, or NULL if the map is unnamed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.