Learn R Programming

freesurferformats (version 1.1.0)

cifti.map.name: Get the name of one named map of a CIFTI-2 file.

Description

Get the name of one named map of a CIFTI-2 file.

Usage

cifti.map.name(cii, dim, map = 1L)

Value

character string, the map name, or NULL if the map is unnamed.

Arguments

cii

an fs.cifti instance, see read.cifti.header.

dim

integer, the matrix dimension that holds the named maps.

map

integer, the number of the map (1-based).