| cifti.merge.axes | R Documentation |
Merge explicitly given axes with the axes of a template.
cifti.merge.axes(axes, template_cii)
axes |
list of axes or |
template_cii |
an |
the merged list of axes, named by matrix dimension.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.