cifti.merge.axes: Merge explicitly given axes with the axes of a template.
Description
Merge explicitly given axes with the axes of a template.
Usage
cifti.merge.axes(axes, template_cii)
Value
the merged list of axes, named by matrix dimension.
Arguments
- axes
list of axes or NULL, see write.cifti.
- template_cii
an fs.cifti object or NULL.