View source: R/read_cifti_header.R
| cifti.parse.child.int.vector | R Documentation |
Parse a required or optional child element holding integer values.
cifti.parse.child.int.vector(node, child_name, filepath = "")
node |
an xml2 node, the parent element. |
child_name |
character string, the name of the child element. |
filepath |
character string, the path of the file the XML was read from. Only used in error messages. |
integer vector, or NULL if the child element is missing or empty.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.