Learn R Programming

freesurferformats (version 1.1.0)

cifti.parse.child.voxel.indices: Parse the optionally present VoxelIndicesIJK child element as a matrix.

Description

Parse the optionally present VoxelIndicesIJK child element as a matrix.

Usage

cifti.parse.child.voxel.indices(node, filepath = "")

Value

an n x 3 integer matrix of 0-based voxel indices, or NULL if the child element is missing or empty.

Arguments

node

an xml2 node, the parent element.

filepath

character string, the path of the file the XML was read from. Only used in error messages.