View source: R/read_cifti_header.R
| cifti.parse.xml | R Documentation |
Parse the CIFTI XML metadata.
cifti.parse.xml(xml_text, filepath = "", niiheader = NULL)
xml_text |
character string, the XML document. |
filepath |
character string, the path of the file the XML was read from. Only used in error messages. |
niiheader |
the NIFTI-2 header of the file, required to determine the sizes of the matrix dimensions. |
an fs.cifti object, see read.cifti.header.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.