Learn R Programming

freesurferformats (version 1.1.0)

cifti.parse.xml: Parse the CIFTI XML metadata.

Description

Parse the CIFTI XML metadata.

Usage

cifti.parse.xml(xml_text, filepath = "", niiheader = NULL)

Value

an fs.cifti object, see read.cifti.header.

Arguments

xml_text

character string, the XML document.

filepath

character string, the path of the file the XML was read from. Only used in error messages.

niiheader

the NIFTI-2 header of the file, required to determine the sizes of the matrix dimensions.