| cifti.read.rows | R Documentation |
Workhorse of read.cifti.rows: read some indices of
matrix dimension 0 without reading the rest of the rows. If a column
selection is given, only those columns are read (they are contiguous blocks
of the file), otherwise the file is read once, in chunks, keeping the
requested rows.
cifti.read.rows(cii, rows, columns = NULL, chunk_values = 4000000L)
cii |
an |
rows |
integer vector, the indices of matrix dimension 0 to read. At least
one index has to be given; the indices are 1-based, see |
columns |
integer vector or |
chunk_values |
integer, the number of data values that are read from the file per chunk. This does not change the result, only the peak memory usage and the I/O granularity, so it is rarely needed: the default of 4 millions values corresponds to about 16 MB. The chunk size is rounded up to a whole number of matrix columns, and the result is the same for every chunk size. |
a numeric matrix with one row per requested row index.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.