| cifti.read.values | R Documentation |
Read raw values from the data section of a CIFTI-2 file.
cifti.read.values(cii, num_values, skip_values = 0L, fh = NULL)
cii |
an |
num_values |
integer, the number of values to read. |
skip_values |
integer, the number of values to skip first. |
fh |
optional connection to the file, positioned at the start of the data
section if |
vector of values, see read.nifti.values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.