Read raw values from the data section of a CIFTI-2 file.
cifti.read.values(cii, num_values, skip_values = 0L, fh = NULL)vector of values, see read.nifti.values.
an fs.cifti instance, see read.cifti.header.
integer, the number of values to read.
integer, the number of values to skip first.
optional connection to the file, positioned at the start of the data
section if skip_values is 0. Will be opened (and closed) if left at NULL.