| cifti.structure.data.dim | R Documentation |
The counterpart of cifti.other.dim for a structure
name: look up the dimension of the file that contains brain models for the
given structure. Needed by the user-facing readers, which get a structure name
from the user and must decide which dimension of the data matrix it refers to.
cifti.structure.data.dim(cii, structure)
cii |
an |
structure |
character string, the canonical name of the brain structure. |
integer, the matrix dimension.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.