Learn R Programming

freesurferformats (version 1.1.0)

cifti.structure.data.dim: Get the matrix dimension a brain structure lives in.

Description

The counterpart of cifti.other.dim for a structure name: look up the dimension of the file that contains brain models for the given structure. Needed by the user-facing readers, which get a structure name from the user and must decide which dimension of the data matrix it refers to.

Usage

cifti.structure.data.dim(cii, structure)

Value

integer, the matrix dimension.

Arguments

cii

an fs.cifti instance, see read.cifti.header.

structure

character string, the canonical name of the brain structure.