The counterpart of cifti.other.dim for a structure
name: look up the dimension of the file that contains brain models for the
given structure. Needed by the user-facing readers, which get a structure name
from the user and must decide which dimension of the data matrix it refers to.
cifti.structure.data.dim(cii, structure)integer, the matrix dimension.
an fs.cifti instance, see read.cifti.header.
character string, the canonical name of the brain structure.