| cifti.structure.from.specifier | R Documentation |
Accept the structure spellings the user-facing readers support: a structure name in any of the supported spellings, or the index of a structure in the file (deprecated, but part of the documented interface of the readers).
cifti.structure.from.specifier(cii, brain_structure)
cii |
an |
brain_structure |
character string or integer, the specifier. |
character string, the canonical structure name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.