Learn R Programming

freesurferformats (version 1.1.0)

cifti.structure.from.specifier: Resolve a user-supplied structure specifier to a canonical name.

Description

Accept the structure spellings the user-facing readers support: a structure name in any of the supported spellings, or the index of a structure in the file (deprecated, but part of the documented interface of the readers).

Usage

cifti.structure.from.specifier(cii, brain_structure)

Value

character string, the canonical structure name.

Arguments

cii

an fs.cifti instance, see read.cifti.header.

brain_structure

character string or integer, the specifier.