Accept the structure spellings the user-facing readers support: a structure name in any of the supported spellings, or the index of a structure in the file (deprecated, but part of the documented interface of the readers).
cifti.structure.from.specifier(cii, brain_structure)character string, the canonical structure name.
an fs.cifti instance, see read.cifti.header.
character string or integer, the specifier.