View source: R/read_cifti_header.R
| cifti.structure.short | R Documentation |
Strip the CIFTI_STRUCTURE_ prefix from a brain structure name,
normalizing it first, see cifti.structure.canonical.
cifti.structure.short(brain_structure)
brain_structure |
character string, a brain structure name in any of the supported spellings. |
character string, the structure name without the prefix (e.g. 'CORTEX_LEFT').
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.