cifti.structure.short: Get the short name of a CIFTI brain structure.
Description
Strip the CIFTI_STRUCTURE_ prefix from a brain structure name,
normalizing it first, see cifti.structure.canonical.
Usage
cifti.structure.short(brain_structure)
Value
character string, the structure name without the prefix (e.g.
'CORTEX_LEFT').
Arguments
- brain_structure
character string, a brain structure name in any of the
supported spellings.