| cifti.surface.vertex.count | R Documentation |
Get the size of the complete surface a brain model refers to. The
Surface elements of the mapping are used if the file has them, otherwise
the SurfaceNumberOfVertices attributes of the brain models are used: the
Surface elements are optional, and the files written by Connectome
Workbench (including the official CIFTI-2 example files) do not contain any,
they report the surface size in the brain models only.
cifti.surface.vertex.count(map, structure)
map |
the indices map, see |
structure |
character string, the canonical name of the brain structure. |
integer, the number of vertices, or NA_integer_ if the structure has
no surface model in this mapping.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.