View source: R/read_cifti_header.R
| cifti.surface.vertex.counts | R Documentation |
Get the number of vertices of the surfaces declared in a CIFTI mapping.
cifti.surface.vertex.counts(map)
map |
a parsed indices map, see |
named integer vector, the number of vertices per canonical brain structure short name (e.g. 'CORTEX_LEFT'). Empty if the mapping declares no surfaces.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.