cifti.surface.vertex.counts: Get the number of vertices of the surfaces declared in a CIFTI mapping.
Description
Get the number of vertices of the surfaces declared in a CIFTI mapping.
Usage
cifti.surface.vertex.counts(map)
Value
named integer vector, the number of vertices per canonical brain
structure short name (e.g. 'CORTEX_LEFT'). Empty if the mapping declares no
surfaces.
Arguments
- map
a parsed indices map, see cifti.parse.indices.map.