| cifti.validate.axes | R Documentation |
Check the things about a set of axes that make a file invalid rather than just unusual: the sizes of the axes, the index ranges of the brain models, the structures a volume model or a parcel refers to, and the label keys of a label table.
cifti.validate.axes(axes)
axes |
list of axes, see |
NULL, invisibly. Stops with a descriptive error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.