Learn R Programming

freesurferformats (version 1.1.0)

cifti.validate.axes: Validate the axes of a CIFTI-2 file.

Description

Check the things about a set of axes that make a file invalid rather than just unusual: the sizes of the axes, the index ranges of the brain models, the structures a volume model or a parcel refers to, and the label keys of a label table.

Usage

cifti.validate.axes(axes)

Value

NULL, invisibly. Stops with a descriptive error.

Arguments

axes

list of axes, see cifti.header.from.axes.