View source: R/read_cifti_header.R
| cifti.validate.brain.models | R Documentation |
Validate the brain model entries of a CIFTI mapping.
cifti.validate.brain.models(map, dim_size, filepath = "")
map |
a parsed indices map, see |
filepath |
character string, the file path, used in error messages. |
NULL, invisibly. Stops with a descriptive error if an entry is
inconsistent.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.