cifti.validate.brain.models: Validate the brain model entries of a CIFTI mapping.
Description
Validate the brain model entries of a CIFTI mapping.
Usage
cifti.validate.brain.models(map, dim_size, filepath = "")
Value
NULL, invisibly. Stops with a descriptive error if an entry is
inconsistent.
Arguments
- map
a parsed indices map, see cifti.parse.indices.map.
- filepath
character string, the file path, used in error messages.