View source: R/read_cifti_header.R
| cifti.validate.dims.coverage | R Documentation |
Check that all matrix dimensions are described exactly once.
cifti.validate.dims.coverage(indices_maps, dim_sizes, filepath = "")
indices_maps |
list of parsed indices maps. |
filepath |
character string, the path of the file the XML was read from. Only used in error messages. |
NULL, invisibly. Stops if a dimension is described twice or not at
all.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.