cifti.validate.dims.coverage: Check that all matrix dimensions are described exactly once.
Description
Check that all matrix dimensions are described exactly once.
Usage
cifti.validate.dims.coverage(indices_maps, dim_sizes, filepath = "")
Value
NULL, invisibly. Stops if a dimension is described twice or not at
all.
Arguments
- indices_maps
list of parsed indices maps.
- filepath
character string, the path of the file the XML was read from.
Only used in error messages.