| cifti.validate.file.extension | R Documentation |
A CIFTI-2 file name states the file type (.dscalar, .pdconn, ...), and
the type decides which matrix index types the two dimensions have. A file whose name
contradicts its content is silently misread by other software, so this is an error.
cifti.validate.file.extension(filepath, file_type)
filepath |
character string, the file name to write. |
file_type |
a one row data.frame, see |
NULL, invisibly. Stops if the file name names a different file type.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.