View source: R/read_cifti_header.R
| cifti.validate.parcels | R Documentation |
Validate the parcels of a CIFTI mapping.
cifti.validate.parcels(map, filepath = "")
map |
a parsed indices map, see |
filepath |
character string, the file path, used in error messages. |
NULL, invisibly. Stops with a descriptive error if a parcel refers
to vertices outside of a declared surface.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.