cifti.validate.parcels: Validate the parcels of a CIFTI mapping.
Description
Validate the parcels of a CIFTI mapping.
Usage
cifti.validate.parcels(map, filepath = "")
Value
NULL, invisibly. Stops with a descriptive error if a parcel refers
to vertices outside of a declared surface.
Arguments
- map
a parsed indices map, see cifti.parse.indices.map.
- filepath
character string, the file path, used in error messages.