| cifti.validate.read.size | R Documentation |
Check the requested allocation against the package safety limit
(see validate_allocation_size) and add a CIFTI specific hint to
the error message if it is exceeded: the data of a large file can be read in
parts by selecting matrix columns, which is not possible in the same way for
other image formats.
cifti.validate.read.size(dims, bytes_per_elem, filepath)
dims |
integer vector, the dimensions of the requested data matrix. |
bytes_per_elem |
numeric, the number of bytes per data value. |
filepath |
character string, the path of the file, used in the error message. |
NULL, invisibly. Stops if the limit is exceeded.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.