Check the requested allocation against the package safety limit
(see validate_allocation_size) and add a CIFTI specific hint to
the error message if it is exceeded: the data of a large file can be read in
parts by selecting matrix columns, which is not possible in the same way for
other image formats.
cifti.validate.read.size(dims, bytes_per_elem, filepath)NULL, invisibly. Stops if the limit is exceeded.
integer vector, the dimensions of the requested data matrix.
numeric, the number of bytes per data value.
character string, the path of the file, used in the error message.