| cifti.xml.add.indices.map | R Documentation |
Add a MatrixIndicesMap element to the Matrix element.
cifti.xml.add.indices.map(matrix_node, axis, dims)
matrix_node |
an xml2 node, the |
axis |
the axis to write, see |
dims |
integer vector, the matrix dimensions the element applies to. |
NULL, invisibly. The element is added as a child of matrix_node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.