cifti.xml.add.indices.map: Add a MatrixIndicesMap element to the Matrix element.
Description
Add a MatrixIndicesMap element to the Matrix element.
Usage
cifti.xml.add.indices.map(matrix_node, axis, dims)
Value
NULL, invisibly. The element is added as a child of matrix_node.
Arguments
- matrix_node
an xml2 node, the Matrix element.
- axis
the axis to write, see cifti.header.from.axes.
- dims
integer vector, the matrix dimensions the element applies to.