| .cifti.label.table.for.users | R Documentation |
The readers document a label table with the column names 'Key', 'Red', 'Green', 'Blue', 'Alpha' and 'Label'; keep that spelling (and the column order) for the user-facing functions, while the internal representation uses lower case column names and also stores the optional label coordinates.
.cifti.label.table.for.users(labels)
labels |
a data.frame as returned by |
a data.frame with the columns 'Key', 'Red', 'Green', 'Blue', 'Alpha' and 'Label'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.