View source: R/dti_tracks_utils.R
| dti.track.bbox | R Documentation |
Streams through the tract file and returns the bounding box of all coordinates, without keeping the coordinates in memory. This is useful to determine the axis limits for plotting a large tractogram.
dti.track.bbox(filepath, chunk_values = 4e+06)
filepath |
character string, path to the |
chunk_values |
integer, the number of payload values to read per chunk.
Advanced tuning parameter, see |
numeric vector of length 6,
c(xmin, xmax, ymin, ymax, zmin, zmax), or NULL if the file
contains no coordinates. The coordinates are in the coordinate system used
by the file, see the note in read.dti.trk.
## Not run:
bbox <- dti.track.bbox("brain.tck");
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.