View source: R/dti_tracks_utils.R
| dti.track.count | R Documentation |
Counts the tracts in a TRK, TCK or TSF file without reading
their coordinates, so this works on arbitrarily large tractograms with a
small and constant amount of memory. This is the equivalent of
tckinfo <file> -count in MRtrix.
dti.track.count(filepath, chunk_values = 4e+06)
filepath |
character string, path to the |
chunk_values |
integer, the number of payload values to read per chunk.
Advanced tuning parameter, see |
integer, the number of tracts in the file. Note that this can differ
from the count entry in the file header, which the MRtrix
documentation explicitly describes as unreliable, and which does not count
empty tracts.
## Not run:
dti.track.count("brain.tck");
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.