Convert quadrangular faces or polygons to triangular ones.
faces.quad.to.tris(quad_faces)*2nx3* integer matrix, the indices of the vertices making up the *2n* tris faces.
nx4 integer matrix, the indices of the vertices making up the *n* quad faces.
Other mesh functions:
read.fs.surface.asc(),
read.fs.surface.bvsrf(),
read.fs.surface.geo(),
read.fs.surface.gii(),
read.fs.surface.ico(),
read.fs.surface.obj(),
read.fs.surface.off(),
read.fs.surface.ply(),
read.fs.surface.vtk(),
read.fs.surface(),
read.mesh.brainvoyager(),
read_nisurfacefile(),
read_nisurface(),
write.fs.surface.asc(),
write.fs.surface.byu(),
write.fs.surface.gii(),
write.fs.surface.mz3(),
write.fs.surface.vtk(),
write.fs.surface()