View source: R/write_analyze.R
| fileopen.write.gz.or.not | R Documentation |
Open a connection for writing, with gzip support based on the file name.
fileopen.write.gz.or.not(filepath)
filepath |
character string, the path of the file to write. |
a connection, either a gzfile or a plain file connection.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.