fileopen.write.gz.or.not: Open a connection for writing, with gzip support based on the file name.
Description
Open a connection for writing, with gzip support based on the file name.
Usage
fileopen.write.gz.or.not(filepath)
Value
a connection, either a gzfile or a plain file connection.
Arguments
- filepath
character string, the path of the file to write.