Learn R Programming

freesurferformats (version 1.1.0)

finite.rows: Check which rows of a matrix consist of finite values only.

Description

Check which rows of a matrix consist of finite values only.

Usage

finite.rows(mat)

Value

logical vector with one entry per row.

Arguments

mat

numeric matrix.