Learn R Programming

freesurferformats (version 1.0.2)

flip2D: Flip a 2D matrix.

Description

Flip a 2D matrix.

Usage

flip2D(slice, how = "horizontally")

Value

2D matrix, the flipped matrix.

Arguments

slice

a 2D matrix

how

character string, one of 'vertically' / 'v' or 'horizontally' / 'h'. Note that flipping horizontally means that the image will be mirrored along the central vertical axis. If NULL is passed, the passed value is returned unaltered.