Learn R Programming

freesurferformats (version 1.1.0)

get.dti.trk.endianness: Determine endianness of TRK file.

Description

Determine endianness of TRK file.

Usage

get.dti.trk.endianness(filepath)

Value

endina character string. one of 'little' or 'big'.

Arguments

filepath

character string, path to file in trk format. Gzip-compressed files are supported as well (the compression is detected from the file content, so a .trk.gz file is read like any other TRK file), which is convenient since tractograms are large and are regularly stored compressed. Note that track files cannot be compressed on the fly for other software: the TrackVis tools and MRtrix do not read compressed track files.