View source: R/dti_tracks_utils.R
| group.start.rows | R Documentation |
Compute the first row of every group in a concatenated matrix.
group.start.rows(lengths)
lengths |
integer vector, the number of rows of each group. |
integer vector with one entry per group.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.