View source: R/read_fs_transform.R
| guess.transform.format | R Documentation |
Guess the format of a transformation file from its extension and its content. Content is needed because the extension '.mat' is used by FSL for text matrices and by ANTs/ITK for binary transformations, which have nothing in common. A file that is identified as an ITK/ANTs transformation is reported as such instead of failing with a parse error, since that format is not supported yet.
guess.transform.format(filepath)
filepath |
character string, the full path to the transform file. |
character string, the file format, one of 'xfm', 'dat', 'lta' or 'fslmat'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.