View source: R/write_fs_transform.R
| guess.writable.transform.format | R Documentation |
Guess the transformation file format from the file name extension, for the formats this package can write.
guess.writable.transform.format(filepath)
filepath |
character string, the full path of the file to write. |
character string, the file format.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.