Learn R Programming

freesurferformats (version 1.1.0)

guess.writable.transform.format: Determine the format of a transformation file to write.

Description

Guess the transformation file format from the file name extension, for the formats this package can write.

Usage

guess.writable.transform.format(filepath)

Value

character string, the file format.

Arguments

filepath

character string, the full path of the file to write.