Learn R Programming

freesurferformats (version 1.1.0)

infinite.rows: Check which rows of a matrix consist of infinite values only.

Description

Check which rows of a matrix consist of infinite values only.

Usage

infinite.rows(mat)

Value

logical vector with one entry per row.

Arguments

mat

numeric matrix.