View source: R/trackvis_affine.R
| inv.ornt.aff | R Documentation |
This is the equivalent of
nibabel.orientations.inv_ornt_aff(): given an orientation and the
shape of the array it was applied to, it returns the affine that maps
coordinates in the transformed space back to coordinates in the original
space.
inv.ornt.aff(ornt, shape)
ornt |
numeric matrix with 2 columns, the orientation. |
shape |
numeric vector, the shape (dimensions) of the array. |
a 4x4 numeric matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.