View source: R/read_fs_transform.R
| itk.key.value | R Documentation |
ITK text transforms store their content as 'key: value' lines, e.g. 'Transform: AffineTransform_float_3_3'. This helper returns the value of such an entry.
itk.key.value(lines, key)
lines |
character vector, the key/value lines of the file. |
key |
character string, the name of the entry, e.g. 'Transform'. |
NULL if the entry does not exist, its value as a character string otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.