itk.key.value: Read the value of a key of an ITK transform file.
Description
ITK text transforms store their content as 'key: value' lines, e.g. 'Transform:
AffineTransform_float_3_3'. This helper returns the value of such an entry.
Usage
itk.key.value(lines, key)
Value
NULL if the entry does not exist, its value as a character string otherwise.
Arguments
- lines
character vector, the key/value lines of the file.
- key
character string, the name of the entry, e.g. 'Transform'.