View source: R/read_fs_transform.R
| itk.numeric.value | R Documentation |
Read a numerical entry of an ITK transform file.
itk.numeric.value(lines, key, filepath)
lines |
character vector, the key/value lines of the file. |
key |
character string, the name of the entry, e.g. 'Parameters'. |
filepath |
character string, the path of the file, used in error messages only. |
numerical vector, the values of the entry. It is an error if the entry is missing or holds no numbers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.