Learn R Programming

freesurferformats (version 1.0.2)

mghheader.crs.orientation: Compute MGH volume orientation string.

Description

Compute MGH volume orientation string.

Usage

mghheader.crs.orientation(header)

Value

character string of length 3, one uppercase letter per axis. Each of the three position is a letter from the alphabet: LRISAP?. The meaning is L for left, R for right, I for inferior, S for superior, P for posterior, A for anterior. If the direction cannot be computed, all three characters are ? for unknown. Of course, each axis (L/R, I/S, A/P) is only represented once in the string.

Arguments

header

Header of the mgh datastructure, as returned by read.fs.mgh.