Create a template NIFTI v2 header. You will have to adapt it for your use case.
Source:R/write_nifti2.R
ni2header.template.RdCreate a template NIFTI v2 header. You will have to adapt it for your use case.
Value
named list, the NIFTI v2 header. All fields are present and filled with values of a proper type. Whether or not they make sense is up to you, but you will most likely have to adapt at least the following fields to your data: dim_raw, datatype, bitpix.
Note
Commonly used data type settings are: for signed integers datatype = 8L and bitpix = 32L; for floats datatype = 16L and bitpix = 32L. See the NIFTI v2 standard for more options. You may want to call ni2header.for.data instead of this function.