powered by
Compute NIFTI dim field for data dimension.
nifti.datadim.to.dimfield(datadim)
NIFTI header dim field, an integer vector of length 8
dim
integer vector, the result of calling dim on your data. The length must be <= 7.
Other NIFTI helper functions: nifti.datadim.from.dimfield()
nifti.datadim.from.dimfield()
nifti.datadim.to.dimfield(c(256, 256, 256))
Run the code above in your browser using DataLab