| nifti.dtype.info | R Documentation |
Compute NIFTI v1 data type info from datatype and bitpix header field.
nifti.dtype.info(datatype, bitpix)
datatype |
integer, the |
bitpix |
integer, the |
named list with entries: mri_dtype: the MRI data type, as used by FreeSurfer for MGH files, r_dtype: the R data type, size: the number of bytes per value, signed: logical, whether the values are signed (only meaningful for integer types, NA for floating point types) and is_float: logical, whether the type is a floating point type.
The signed entry matters for reading the data: an unsigned 8 bit value of 200 is read as -56 if it is read as a signed value, which is a silent change of the data. See read.nifti.values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.