Learn R Programming

freesurferformats (version 1.1.0)

nifti.dtype.info: Compute NIFTI v1 data type info from datatype and bitpix header field.

Description

Compute NIFTI v1 data type info from datatype and bitpix header field.

Usage

nifti.dtype.info(datatype, bitpix)

Value

named list with entries: mri_dtype: the MRI data type, as used by FreeSurfer for MGH files, r_dtype: the R data type, size: the number of bytes per value, signed: logical, whether the values are signed (only meaningful for integer types, NA for floating point types) and is_float: logical, whether the type is a floating point type.

Arguments

datatype

integer, the datatype NIFTI v1 header field

bitpix

integer, the bitpix NIFTI v1 header field