Compute NIFTI v1 data type info from datatype and bitpix header field.
nifti.dtype.info(datatype, bitpix)named list with entries: mri_dtype: the MRI data type, as used by FreeSurfer for MGH files, r_dtype: the R data type, size: the number of bytes per value, signed: logical, whether the values are signed (only meaningful for integer types, NA for floating point types) and is_float: logical, whether the type is a floating point type.
integer, the datatype NIFTI v1 header field
integer, the bitpix NIFTI v1 header field