Learn R Programming

freesurferformats (version 1.0.2)

nifti.dtype.info: Compute NIFTI v1 data type info from datatype and bitpix header field.

Description

Compute NIFTI v1 data type info from datatype and bitpix header field.

Usage

nifti.dtype.info(datatype, bitpix)

Value

named list with entries: mri_dtype: the MRI data type, as used by FreeSurfer for MGH files, r_dtype: the R data type.

Arguments

datatype

integer, the datatype NIFTI v1 header field

bitpix

integer, the bitpix NIFTI v1 header field