| nifti.info.from.oro.instance | R Documentation |
oro.nifti instance into a plain list.Extract the header information and the data of an oro.nifti instance into a plain list.
nifti.info.from.oro.instance(nifti_img)
nifti_img |
an instance of class |
named list, see nifti.info.from.file.
The data scaling fields of the instance are not applied here, they are expected to be applied already:
instances read by oro.nifti::readNIfTI are rescaled unless rescale_data = FALSE was used.
nifti.info.from.file
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.