nifti.info.from.oro.instance: Extract the header information and the data of an oro.nifti instance into a plain list.
Description
Extract the header information and the data of an oro.nifti instance into a plain list.
Usage
nifti.info.from.oro.instance(nifti_img)
Value
named list, see nifti.info.from.file.
Arguments
- nifti_img
an instance of class nifti from the oro.nifti package.