| nifti.resolve.filepath | R Documentation |
Resolve the path of a NIFTI file which is given without a file extension.
nifti.resolve.filepath(filepath)
filepath |
character string, the path to a NIFTI file. |
character string, the path of an existing file. If filepath itself does not exist, the usual
NIFTI file extensions are appended to it and the first existing file is returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.