nifti.resolve.filepath: Resolve the path of a NIFTI file which is given without a file extension.
Description
Resolve the path of a NIFTI file which is given without a file extension.
Usage
nifti.resolve.filepath(filepath)
Value
character string, the path of an existing file. If filepath itself does not exist, the usual
NIFTI file extensions are appended to it and the first existing file is returned.
Arguments
- filepath
character string, the path to a NIFTI file.