View source: R/nifti2_extensions.R
| nifti2.extension.size | R Documentation |
A NIFTI v2 header extension occupies a multiple of 16 bytes in the file, because the payload is padded with NUL bytes. See nifti2.extension for details.
nifti2.extension.size(extension)
extension |
a NIFTI v2 header extension, a named list with entries 'ecode' and 'content', see |
integer, the size of the extension in bytes, as it is stored in the file. This includes the 8 bytes of meta data (the size and code fields) and the padding.
Other nifti2 extensions:
nifti2.extension(),
nifti2.extension.content(),
nifti2.extension.text(),
nifti2.get.extension()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.