View source: R/nifti2_extensions.R
| nifti2.read.extensions | R Documentation |
Read the header extensions of a NIFTI v2 file.
nifti2.read.extensions(fh, available, endian = "little")
fh |
filehandle, a connection to a NIFTI v2 file, positioned at the first byte after the fixed-size header (i.e., at the extension flag bytes). |
available |
integer, the number of bytes available for header extensions, i.e., |
endian |
character string, the endianness of the file, either 'little' or 'big'. |
list of header extensions, see nifti2.extension. Empty list if the file has no extensions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.