Read the header extensions of a NIFTI v2 file.
nifti2.read.extensions(fh, available, endian = "little")list of header extensions, see nifti2.extension. Empty list if the file has no extensions.
filehandle, a connection to a NIFTI v2 file, positioned at the first byte after the fixed-size header (i.e., at the extension flag bytes).
integer, the number of bytes available for header extensions, i.e., vox_offset minus the 544 bytes of the fixed-size header and the extension flag.
character string, the endianness of the file, either 'little' or 'big'.