View source: R/nifti2_extensions.R
| nifti2.strip.nul | R Documentation |
Remove all NUL bytes from a raw vector. This is needed for the payload of NIFTI v2 header extensions, which are padded with NUL bytes, and for the payload of MATLAB files, but the function is not specific to any format.
nifti2.strip.nul(rawdata)
rawdata |
raw vector or integer vector with values in range 0 to 255. |
raw vector, the input without any NUL bytes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.