View source: R/nifti2_extensions.R
| nifti2.trailing.nul.removed | R Documentation |
Remove the NUL bytes at the end of a raw vector, but keep any NUL bytes before them. This is needed for the payload of NIFTI v2 header extensions, which is padded with NUL bytes to a multiple of 16 bytes, but can in theory contain NUL bytes as part of the payload.
nifti2.trailing.nul.removed(rawdata)
rawdata |
raw vector or integer vector with values in range 0 to 255. |
raw vector, the input without trailing NUL bytes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.