View source: R/nifti2_extensions.R
| nifti2.write.extensions | R Documentation |
Write the header extensions of a NIFTI v2 file.
nifti2.write.extensions(fh, extensions, endian = "little")
fh |
filehandle, a connection to a NIFTI v2 file, positioned at the first byte after the fixed-size header (i.e., where the extension flag bytes go). |
extensions |
list of header extensions, see |
endian |
character string, the endianness of the file, either 'little' or 'big'. |
integer, the number of bytes written (the extension flag bytes plus all extensions). The data must start at 544 + <return value>.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.