Write the header extensions of a NIFTI v2 file.
nifti2.write.extensions(fh, extensions, endian = "little")integer, the number of bytes written (the extension flag bytes plus all extensions). The data must start at 544 + <return value>.
filehandle, a connection to a NIFTI v2 file, positioned at the first byte after the fixed-size header (i.e., where the extension flag bytes go).
list of header extensions, see nifti2.extension. An empty list writes the extension flag for 'no extensions present'.
character string, the endianness of the file, either 'little' or 'big'.