| nrrd.field | R Documentation |
Look up a field in a parsed NRRD header.
nrrd.field(fields, name, default = NULL)
fields |
named list, the fields of the header, as returned by |
name |
character string, the field name to look up, e.g. 'space origin'. |
default |
the value to return when the field is not present. |
the value of the field, or default when the field is not present.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.