Learn R Programming

freesurferformats (version 1.1.0)

nrrd.field: Look up a field in a parsed NRRD header.

Description

Look up a field in a parsed NRRD header.

Usage

nrrd.field(fields, name, default = NULL)

Value

the value of the field, or default when the field is not present.

Arguments

fields

named list, the fields of the header, as returned by nrrd.parse.header.

name

character string, the field name to look up, e.g. 'space origin'.

default

the value to return when the field is not present.