| nrrd.field.key | R Documentation |
NRRD field names are matched case-insensitively and some fields are spelled in two ways ('line skip' and 'lineskip', 'data file' and 'datafile'), so a key is computed by lowercasing the name and dropping everything that is not a letter or a digit.
nrrd.field.key(name)
name |
character string, the field name as it occurs in the file. |
character string, the normalized key.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.