Learn R Programming

freesurferformats (version 1.1.0)

nrrd.field.key: Parse a NRRD header field name into a lookup key.

Description

NRRD field names are matched case-insensitively and some fields are spelled in two ways ('line skip' and 'lineskip', 'data file' and 'datafile'), so a key is computed by lowercasing the name and dropping everything that is not a letter or a digit.

Usage

nrrd.field.key(name)

Value

character string, the normalized key.

Arguments

name

character string, the field name as it occurs in the file.