Learn R Programming

freesurferformats (version 1.1.0)

nrrd.read.remainder: Read the remaining bytes of a connection.

Description

Reads everything from the current position to the end of the file, in chunks, to keep the peak memory of the intermediate buffers bounded. This is used for the bzip2 encoding, which R cannot decompress as a stream.

Usage

nrrd.read.remainder(con)

Value

raw vector.

Arguments

con

a connection opened in binary read mode.