| nrrd.resolve.data.files | R Documentation |
Determines where the data of a NRRD file are stored: in the file itself, in a file named by the 'data file' header field (a path relative to the directory of the header file), or in the several files that the 'data file: LIST' mode names.
nrrd.resolve.data.files(fields, data_file_names, filepath)
fields |
named list, the parsed header fields. |
data_file_names |
character vector or NULL, the file names of the LIST mode. |
filepath |
character string, path to the header file. |
character vector of data file paths, or NULL when the data are attached to the header file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.