Used for the NRRD 'line skip' header field, which announces that the data does not
start directly behind the header but behind a number of newline-terminated lines. Unlike
skip.connection.bytes, this has to work for connections that cannot be seeked in, so the
bytes are read and discarded.
nrrd.skip.lines(con, num_lines, filepath = "")TRUE, invisibly.
a connection opened in binary read mode.
integer, the number of lines to skip.
character string, used in error messages only.