View source: R/read_dti_tcktsf.R
| open.mrtrix.payload | R Documentation |
Parses and validates the header and returns everything needed to
read the payload. The caller is responsible for closing con.
## S3 method for class 'mrtrix.payload'
open(filepath, max_tracks = Inf)
filepath |
character string, path to the file. |
max_tracks |
numeric, the maximum number of tracks that will be read. Used to decide whether an up-front allocation check makes sense. |
named list with entries con, header, offset,
dsize, endian, values_per_point, gzipped,
is_tck and expected_groups.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.