Learn R Programming

freesurferformats (version 1.1.0)

open.mrtrix.payload: Open the payload of an MRtrix TCK/TSF file for reading.

Description

Parses and validates the header and returns everything needed to read the payload. The caller is responsible for closing con.

Usage

# S3 method for mrtrix.payload
open(filepath, max_tracks = Inf)

Value

named list with entries con, header, offset, dsize, endian, values_per_point, gzipped, is_tck and expected_groups.

Arguments

filepath

character string, path to the file.

max_tracks

numeric, the maximum number of tracks that will be read. Used to decide whether an up-front allocation check makes sense.