View source: R/read_dti_tcktsf.R
| parse.mrtrix.datatype | R Documentation |
Validate and describe the datatype entry of an MRtrix TCK/TSF header.
parse.mrtrix.datatype(header, filepath = "")
header |
named list, the parsed header. |
filepath |
character string, the path of the file, used in messages only. |
named list with entries dsize (bytes per value) and
endian ('little' or 'big').
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.