parse.mrtrix.datatype: Validate and describe the datatype entry of an MRtrix TCK/TSF header.
Description
Validate and describe the datatype entry of an MRtrix TCK/TSF header.
Usage
parse.mrtrix.datatype(header, filepath = "")
Value
named list with entries dsize (bytes per value) and
endian ('little' or 'big').
Arguments
- header
named list, the parsed header.
- filepath
character string, the path of the file, used in messages only.