View source: R/read_dti_tcktsf.R
| parse.mrtrix.file.entry | R Documentation |
The entry has the form 'file: . OFFSET', where the file name part must be a single dot for single-file TCK/TSF files and the offset gives the byte position at which the binary payload starts.
parse.mrtrix.file.entry(header, filepath = "")
header |
named list, the parsed header. |
filepath |
character string, the path of the file, used in messages only. |
named list with entries filename_part (character) and
offset (numeric).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.