View source: R/read_dti_tcktsf.R
| parse.mrtrix.header | R Documentation |
Splits each header line at its first colon. Values may contain
colons (e.g., in command_history entries), they are preserved. Lines
without a colon are ignored, as the MRtrix reference implementation does.
Keys that occur more than once are collected into a vector.
parse.mrtrix.header(lines, filepath = "")
lines |
character vector, the header lines, including the first line and the terminating 'END' line. |
filepath |
character string, the path of the file, used in error messages only. |
named list, the parsed header.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.