Splits each header line at its first colon. Values may contain
colons (e.g., in command_history entries), they are preserved. Lines
without a colon are ignored, as the MRtrix reference implementation does.
Keys that occur more than once are collected into a vector.
parse.mrtrix.header(lines, filepath = "")named list, the parsed header.
character vector, the header lines, including the first line and the terminating 'END' line.
character string, the path of the file, used in error messages only.