named list with the ANALYZE 7.5 header fields, in the field naming of the format specification. See
analyzeheader.template for a description of all of them. In addition to the fields of the
specification, the following entries are present:
endian
character string, the endianness of the file, 'little' or 'big'. It is detected from the
sizeof_hdr field.
magic
character string, the 4 bytes at offset 344 (which are the smin field of the ANALYZE
specification), interpreted as a string. It is empty for ANALYZE files, see is.analyze.file.
header_format
character string, always 'analyze' here. The other variant of the two-file format is
reported as 'nifti1_pair', see read.fs.volume.analyze.
spm_origin
integer vector of length 3, the interpretation that SPM gives to the originator field:
the voxel coordinates of the image origin, as stored in the first 6 bytes of the field. It is NULL if all
of them are zero, which means that the field does not store an origin.
originator_bytes
raw vector of length 10, the unmodified content of the originator field. The
originator entry is the same content with the zero bytes removed and interpreted as a string, which loses
information for the files in which SPM stores the image origin there.
filepath_header, filepath_image
character strings, the paths of the two files of the pair.