| read.dti.trk.header | R Documentation |
Reads and parses the 1000 byte header of a TRK file without touching the track data. This is cheap even for huge tractograms and can be used to inspect a file before deciding whether to read its tracks.
read.dti.trk.header(filepath, shift_origin = TRUE)
filepath |
character string, path to a file in TRK format. Gzip-compressed
files (typically named |
shift_origin |
logical, whether to compute the corrected |
named list, the header. It contains all fields of the TRK header as
described at http://trackvis.org/docs/?subsect=fileformat, plus
vox2ras (the matrix stored in the file) and, if
shift_origin is TRUE, vox2ras_corrected.
## Not run:
hdr <- read.dti.trk.header("brain.trk");
hdr$n_count; # number of tracks stated in the header
hdr$voxel_order;
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.