read.fs.transform: Load transformation matrix from a file.
Description
Load transformation matrix from a file.
Usage
read.fs.transform(filepath, format = "auto")
Value
named list, the 'matrix field contains a '4x4 numerical matrix, the transformation matrix. Other fields may exist, depending on the parsed format.
Arguments
filepath
character string, the full path to the transform file.
format
character string, the file format. Currently 'auto' (guess based on file extension), 'xfm' (for xform format) or 'dat' (for tkregister style, e.g. register.dat) are supported.