View source: R/read_dti_tcktsf.R
| read.mrtrix.header | R Documentation |
Reads lines up to and including the terminating 'END' line. The number of header lines is not limited, headers of real files contain a variable number of entries (command history, comments, ROI specifications).
read.mrtrix.header(filepath)
filepath |
character string, path to the file. |
named list with entries lines (the raw header lines),
gzipped (logical) and header (the parsed key-value pairs).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.