Read num_values voxel values of the data type described by the datatype and bitpix fields of
a header, in the endianness of the file. This is the shared low level reading code of the NIFTI and ANALYZE
readers.
read.nifti.values(fh, datatype, bitpix, num_values, endian)numeric or integer vector of length num_values, the raw values as they are stored in the file.
connection to read from, positioned at the first value.
integer, the datatype header field.
integer, the bitpix header field.
integer, the number of values to read.
character string, the endianness of the file, 'little' or 'big'.