| read.nifti2.header | R Documentation |
Read NIFTI v2 header from file.
read.nifti2.header(filepath)
filepath |
path to a NIFTI v2 file. |
named list with NIFTI 2 header fields. The header extensions, if the file has any, are returned in
the field extensions, a list in which each entry is one header extension as created by
nifti2.extension (i.e., a list with the entries 'ecode' and 'content'). CIFTI2 files store
their XML metadata in such an extension, see nifti2.get.extension.
write.nifti2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.