powered by
Tries to read all files which can be constructed from the base path and the given extensions.
read_nisurface(filepath_noext, extensions = c("", ".asc", ".gii"), ...)
an instance of fs.surface, read from the file. See read.fs.surface for details. If none of the reader methods succeed, an error is raised.
fs.surface
read.fs.surface
character string, the full path to the input surface file without file extension.
vector of character strings, the file extensions to try.
parameters passed on to read_nisurfacefile. Allows you to set the methods.
read_nisurfacefile
methods
Other mesh functions: faces.quad.to.tris(), read.fs.surface(), read.fs.surface.asc(), read.fs.surface.bvsrf(), read.fs.surface.geo(), read.fs.surface.gii(), read.fs.surface.ico(), read.fs.surface.obj(), read.fs.surface.off(), read.fs.surface.ply(), read.fs.surface.vtk(), read.mesh.brainvoyager(), read_nisurfacefile(), write.fs.surface(), write.fs.surface.asc(), write.fs.surface.byu(), write.fs.surface.gii(), write.fs.surface.mz3(), write.fs.surface.vtk()
faces.quad.to.tris()
read.fs.surface()
read.fs.surface.asc()
read.fs.surface.bvsrf()
read.fs.surface.geo()
read.fs.surface.gii()
read.fs.surface.ico()
read.fs.surface.obj()
read.fs.surface.off()
read.fs.surface.ply()
read.fs.surface.vtk()
read.mesh.brainvoyager()
read_nisurfacefile()
write.fs.surface()
write.fs.surface.asc()
write.fs.surface.byu()
write.fs.surface.gii()
write.fs.surface.mz3()
write.fs.surface.vtk()
if (FALSE) { surface_filepath_noext <- paste(get_optional_data_filepath("subjects_dir/subject1/surf/"), "lh.white", sep = "" ) mesh <- read_nisurface(surface_filepath_noext) mesh }
Run the code above in your browser using DataLab