| [[.fs.tracts | R Documentation |
For TCK data (see read.dti.tck), a tract is an n x 3
numeric matrix of coordinates. For TRK data (see read.dti.trk), a
tract is a named list with the entries coords (n x 3 matrix),
num_points (integer), scalars (n x n_scalars matrix or NULL)
and properties (numeric vector or NULL).
This returns a copy of the requested tract, the data is stored in a single matrix internally.
## S3 method for class 'fs.tracts'
x[[i]]
x |
an |
i |
positive integer, the index of the tract to retrieve. |
the tract, see the description.
## Not run:
tck <- read.dti.tck("brain.tck");
first_tract_coords <- tck$tracks[[1]];
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.