View source: R/dti_tracks_utils.R
| subset.groups | R Documentation |
Extract selected groups from a concatenated matrix.
## S3 method for class 'groups'
subset(points, lengths, sel)
points |
numeric matrix holding the concatenated rows of all groups. |
lengths |
integer vector with the number of rows of each group. |
sel |
integer vector, the indices of the groups to extract. |
named list with entries points (matrix with the rows of the
selected groups) and lengths (their lengths).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.