Learn R Programming

freesurferformats (version 1.1.0)

subset.groups: Extract selected groups from a concatenated matrix.

Description

Extract selected groups from a concatenated matrix.

Usage

# S3 method for groups
subset(points, lengths, sel)

Value

named list with entries points (matrix with the rows of the selected groups) and lengths (their lengths).

Arguments

points

numeric matrix holding the concatenated rows of all groups.

lengths

integer vector with the number of rows of each group.

sel

integer vector, the indices of the groups to extract.