Learn R Programming

freesurferformats (version 1.1.0)

summary.fs.transform: Summarize an fs.transform instance.

Description

Compute the properties of a transformation in a machine-readable form, for printing or for further processing.

Usage

# S3 method for fs.transform
summary(object, ...)

Value

named list with the entries 'format', 'source', 'space_in', 'space_out', 'voxel_base', 'src', 'dst' (the corresponding fields of the transform), 'translation' (numerical vector of length 3, the last column of the matrix), 'determinant', 'is_affine' (logical, whether the last row of the matrix is '0 0 0 1') and 'is_invertible' (logical).

Arguments

object

an fs.transform instance.

...

ignored, only present for consistency with the generic.

See Also

Other header coordinate space: invert.fs.transform(), is.fs.transform(), mghheader.is.ras.valid(), mghheader.ras2vox(), mghheader.ras2vox.tkreg(), mghheader.scanner2tkreg(), mghheader.tkreg2scanner(), mghheader.vox2ras(), mghheader.vox2ras.tkreg(), print.fs.transform(), read.fs.transform(), read.fs.transform.dat(), read.fs.transform.fslmat(), read.fs.transform.itk(), read.fs.transform.lta(), read.fs.transform.xfm(), sm0to1(), sm1to0(), transform2lps(), transform2ras(), transform2voxel(), transform2world(), write.fs.transform(), write.fs.transform.dat(), write.fs.transform.fslmat(), write.fs.transform.itk(), write.fs.transform.lta(), write.fs.transform.xfm()

Examples

Run this code
tf <- read.fs.transform(system.file("extdata", "register.dat",
  package = "freesurferformats", mustWork = TRUE
))
summary(tf)$space_out

Run the code above in your browser using DataLab