Computes the affine that turns the streamlines stored in a TRK
file into RAS+ mm coordinates in which a coordinate of (0,0,0) is the center
of the first voxel, which is the convention used by 'nibabel', DIPY and the
TRX format. The stored streamlines refer to the voxel corners and are in
"voxelmm" space, so this combines the stored matrix with the voxel sizes,
the half-voxel offset, and the orientation stored in the voxel_order
header field.
trackvis.affine.to.rasmm(header)a 4x4 numeric matrix.
named list, the header of a TRK file as returned by
read.dti.trk.header.