View source: R/trackvis_affine.R
| transform.bbox | R Documentation |
Returns the axis-aligned bounding box of the transformed box. For a linear transformation the extremes of the image of a box are attained at its corners, so transforming the 8 corners gives the exact bounding box of the transformed data.
## S3 method for class 'bbox'
transform(bbox, affine)
bbox |
numeric vector of length 6,
|
affine |
4x4 numeric matrix. |
numeric vector of length 6.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.