Learn R Programming

freesurferformats (version 1.1.0)

transform.bbox: Transform a bounding box with an affine.

Description

Returns the axis-aligned bounding box of the transformed box. For a linear transformation the extremes of the image of a box are attained at its corners, so transforming the 8 corners gives the exact bounding box of the transformed data.

Usage

# S3 method for bbox
transform(bbox, affine)

Value

numeric vector of length 6.

Arguments

bbox

numeric vector of length 6, c(xmin, xmax, ymin, ymax, zmin, zmax).

affine

4x4 numeric matrix.