Learn R Programming

freesurferformats (version 1.1.0)

transform.descriptor.path: Get the file path recorded in a volume descriptor.

Description

Get the file path recorded in a volume descriptor.

Usage

# S3 method for descriptor.path
transform(descriptor)

Value

NULL or character string.

Arguments

descriptor

NULL or a volume descriptor, see volume.descriptor.