View source: R/read_fs_transform.R
| transform.file.sniff.text | R Documentation |
Read the beginning of a file and return the printable characters it contains, so that the file can be identified by markers in its content without failing on binary data.
## S3 method for class 'file.sniff.text'
transform(filepath, num_bytes = 256L)
filepath |
character string, the path to the file. |
num_bytes |
integer, the number of bytes to inspect. |
character string, the printable characters of the beginning of the file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.