View source: R/transforms_convert.R
| transform.geometry.for.side | R Documentation |
Use the geometry recorded in the transformation itself if it is available, and the volume passed by the caller otherwise.
## S3 method for class 'geometry.for.side'
transform(tf, side, volume = NULL)
tf |
an |
side |
character string, either 'src' or 'dst'. |
volume |
|
NULL or a geometry list as returned by volume.geometry.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.