Learn R Programming

freesurferformats (version 1.1.0)

transform.geometry.for.side: Determine the volume geometry of one side of a transformation.

Description

Use the geometry recorded in the transformation itself if it is available, and the volume passed by the caller otherwise.

Usage

# S3 method for geometry.for.side
transform(tf, side, volume = NULL)

Value

NULL or a geometry list as returned by volume.geometry.

Arguments

tf

an fs.transform instance.

side

character string, either 'src' or 'dst'.

volume

NULL or a volume, see volume.geometry.