View source: R/write_fs_transform.R
| transform.matrix.row.lines | R Documentation |
The transformation file formats store the matrix as text, and the values are written with enough significant digits so that reading the file back gives the exact same double values. Fewer digits are not enough: 15 digits, as used by some other tools, lose up to a few units in the last place of a double.
## S3 method for class 'matrix.row.lines'
transform(matrix)
matrix |
numerical matrix, the matrix to format. |
character vector with one entry per row of the matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.