Learn R Programming

freesurferformats (version 1.1.0)

transform.world.frame: Determine the frame of the world space of a transformation.

Description

The world space that a transformation between voxel coordinates refers to depends on the format it was read from: an FSL matrix uses the FSL convention, see fsl.scaled.voxel.matrix, while the matrices of the other formats use the RAS space of the volume headers. The frame is taken from the volume descriptors if they state it and is derived from the format otherwise, so that transform2world and transform2voxel always agree.

Usage

# S3 method for world.frame
transform(tf)

Value

character string, either 'fsl' or 'scanner'.

Arguments

tf

an fs.transform instance.