| vtk.as.indices | R Documentation |
Convert values that are used as indices to integers.
vtk.as.indices(values, filepath)
values |
numeric vector, the values to convert. |
filepath |
character string, the file the values were read from. |
integer vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.