Learn R Programming

freesurferformats (version 1.1.0)

vtk.as.indices: Convert values that are used as indices to integers.

Description

Convert values that are used as indices to integers.

Usage

vtk.as.indices(values, filepath)

Value

integer vector.

Arguments

values

numeric vector, the values to convert.

filepath

character string, the file the values were read from.