vtk.as.indices: Convert values that are used as indices to integers.
Description
Convert values that are used as indices to integers.
Usage
vtk.as.indices(values, filepath)
Arguments
- values
numeric vector, the values to convert.
- filepath
character string, the file the values were read from.