| vtk.check.triangles | R Documentation |
Check that all cells of the requested type are triangles.
vtk.check.triangles(cells, filepath)
cells |
list of integer vectors, as returned by |
filepath |
character string, the file the cells were read from. |
NULL, invisibly. Stops if a cell is not a triangle.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.