Learn R Programming

freesurferformats (version 1.1.0)

vtk.check.triangles: Check that all cells of the requested type are triangles.

Description

Check that all cells of the requested type are triangles.

Usage

vtk.check.triangles(cells, filepath)

Value

NULL, invisibly. Stops if a cell is not a triangle.

Arguments

cells

list of integer vectors, as returned by vtk.parse.cell.section.

filepath

character string, the file the cells were read from.