Learn R Programming

freesurferformats (version 1.1.0)

vtk.next.section: Read the next section header line of a VTK legacy file.

Description

Read the next section header line of a VTK legacy file.

Usage

vtk.next.section(reader)

Value

named list with the entries 'keyword' (character, e.g. 'POLYGONS') and 'args' (character vector, the remaining tokens of the line), or NULL

at the end of the file.

Arguments

reader

an environment as returned by vtk.reader.new.