Learn R Programming

freesurferformats (version 1.1.0)

vtk.parse.count: Read a non-negative integer from a VTK section header.

Description

Read a non-negative integer from a VTK section header.

Usage

vtk.parse.count(value, filepath, what)

Value

single integer.

Arguments

value

character string, the token to parse.

filepath

character string, the file being read, for error messages.

what

character string, a description of the value, for error messages.