Learn R Programming

freesurferformats (version 1.1.0)

vtk.reader.new: Create the low-level state used while reading a VTK legacy file.

Description

Opens a connection to the file (transparently handling gzip compression) and initializes the lookahead buffer. The returned environment is passed to the other vtk.* functions, which mutate its state while they consume the file.

Usage

vtk.reader.new(filepath)

Value

an environment with the class 'vtk.reader'.

Arguments

filepath

character string, path to the VTK file.