View source: R/write_fs_surface.R
| vtk.write.surface.ascii | R Documentation |
Write the sections of a triangular mesh in VTK ASCII format.
vtk.write.surface.ascii(con, vertex_coords, faces, version)
con |
a connection opened for writing. |
vertex_coords |
n x 3 matrix of doubles, the vertex coordinates. |
faces |
n x 3 matrix of integers, the vertex indices of the faces, already converted to zero-based indices. |
version |
character string, either '4.2' or '5.1'. |
NULL, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.