View source: R/write_fs_surface.R
| vtk.write.surface.binary | R Documentation |
Write the sections of a triangular mesh in binary VTK format.
vtk.write.surface.binary(con, vertex_coords, faces, version)
con |
a connection opened for binary writing. |
vertex_coords |
n x 3 matrix of doubles, the vertex coordinates. |
faces |
n x 3 matrix of integers, the vertex indices of the faces, already converted to zero-based indices. |
version |
character string, either '4.2' or '5.1'. |
NULL, invisibly.
Binary data in the VTK legacy format is always big endian, the format has no way of expressing a different byte order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.