Learn R Programming

freesurferformats (version 1.1.0)

write.analyze.char.field: Write a fixed length character field of an ANALYZE 7.5 header.

Description

Write a fixed length character field of an ANALYZE 7.5 header.

Usage

write.analyze.char.field(fh, field_value, field_length, return_bytes = FALSE)

Value

invisible NULL (or the raw vector of length field_length if return_bytes is TRUE), called for the side effect of writing to the connection.

Arguments

fh

connection to write to.

field_value

character string, the value to write.

field_length

integer, the length of the field in bytes.

return_bytes

logical, whether to return the raw bytes instead of writing them to the connection.