Write a fixed length character field of an ANALYZE 7.5 header.
write.analyze.char.field(fh, field_value, field_length, return_bytes = FALSE)invisible NULL (or the raw vector of length field_length if return_bytes is TRUE), called for
the side effect of writing to the connection.
connection to write to.
character string, the value to write.
integer, the length of the field in bytes.
logical, whether to return the raw bytes instead of writing them to the connection.