View source: R/write_dwi_gradients.R
| write.dti.bval | R Documentation |
Writes the diffusion weighting of each volume of a diffusion MRI dataset to a plain text file, which is the bvals part of the FSL bvecs/bvals format.
write.dti.bval(filepath, bval, layout = "components")
filepath |
character string, path to the output file. The conventional
extension is |
bval |
numeric vector, the b-value of each volume, in s/mm^2. |
layout |
character string, one of 'components' or 'volumes'.
|
NULL, invisibly. Called for the side effect of writing the file.
Other dti functions:
read.dti.bval(),
read.dti.bvec(),
read.dti.grad(),
read.dti.gradients(),
write.dti.bvec(),
write.dti.grad()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.