Write an annotation to a GIFTI XML file.
Note
This function does not write a GIFTI file that is valid according to the specification: it stores extra color data in the Label nodes, and there is more than one Label in the LabelTable node.
See also
Other atlas functions:
colortable.from.annot(),
read.fs.annot(),
read.fs.colortable(),
write.fs.annot(),
write.fs.colortable()
Other gifti writers:
write.fs.label.gii(),
write.fs.morph.gii(),
write.fs.surface.gii()
Examples
if (FALSE) { # \dontrun{
# Load annotation
annot_file <- system.file("extdata", "lh.aparc.annot.gz",
package = "freesurferformats",
mustWork = TRUE
)
annot <- read.fs.annot(annot_file)
# New method: write the annotation instance:
write.fs.annot.gii(tempfile(fileext = ".annot"), annot)
} # }