Writes the 'solid' block of the ASCII variant of the STL format,
with 7 lines per face ('facet normal', 'outer loop', 3 'vertex' lines,
'endloop', 'endfacet'). This is the layout that
read.fs.surface.stl.ascii and other STL readers expect.
write.stl.ascii(con, vertex_coords, faces, face_normals, solid_name = "mesh")NULL, invisibly. The data are written to con.
a connection opened in binary write mode, the file is written as text through it.
n x 3 matrix of doubles, the vertex coordinates.
n x 3 matrix of integers, the vertex indices of the triangles.
n x 3 matrix of doubles, the normals of the faces, see
mesh.face.normals.
character string, the name of the mesh.